##################################################
# Calculations of all Newton Subdivisions Cell 2 #
##################################################

# We use the calculations of the 8 subdivisions of the TypeIICone done in "ComputingSubdivisionsCoefficientsyz.sage" in order to compute the possible Newton Subdivisions for the yz-projection on each of the 8 cells. This will detect possible subdivisions of the original 8 cells of the TypeIICone.

# Once the chambers are computed, we project back to the first 4 coordinates. We compute the pieces and check for overlaps. After turning the collection into a decomposition of Cell0, we find the facets and rays. We only consider lower dimensional faces and sample points if they are in the relative interior of the original Cell, since otherwise these points will be taken care of when analyzing the corresponding cell in the boundary.

# The required functions are obtain by loading the following auxiliary file:
load("macroslocalJInvariantComputationsAndPrimesWithBadReduction.sage")

#########################################
# Generate the ambient ring and Weights #
#########################################

AXs = [var("b5"),var("b4"),var("b34"), var("b2"), var("x"), var("y")]
RX = PolynomialRing(QQ,AXs)
KX = FractionField(R);

Rxy = PolynomialRing(QQ, [var("x"), var("y")])

###########################
# Grobner Cones and Cells #
###########################

# We load the 9 cells the variables are As = [var("b5"),var("b4"),var("b34"), var("b2")]

allPiecesTypeIICone = load("allPiecesTypeIICone.sobj")

Cell = allPiecesTypeIICone[2]

# Cell.Hrepresentation()
# (An inequality (0, 0, -1, 1) x + 0 >= 0,
#  An inequality (1, -2, 0, 1) x + 0 >= 0,
#  An inequality (0, 1, 0, -1) x + 0 >= 0)

# Cell.lines()
# (A line in the direction (1, 1, 1, 1),)

# We compute the inequalities by re-embedding in AXS
ieqsCell = inequalitiesOfReembeddedPolyhedron(Cell)
eqnsCell = equationsOfReembeddedPolyhedron(Cell)

# ieqsCell
# [(0, 0, 0, -1, 1, 0, 0), (0, 1, -2, 0, 1, 0, 0), (0, 0, 1, 0, -1, 0, 0)]
# eqnsCell
# []

# We re-embedd the Cell in R^6:

newCell = Polyhedron(ieqs=ieqsCell, eqns = eqnsCell)
#  newCell.Hrepresentation()
# (An inequality (0, 0, -1, 1, 0, 0) x + 0 >= 0,
#  An inequality (0, 1, 0, -1, 0, 0) x + 0 >= 0,
#  An inequality (1, -2, 0, 1, 0, 0) x + 0 >= 0)

# We load the Grobner fans and the Maximal Cones for all 9 cells:
allGfm =load("allGfmCells0to8.sobj")
PolyMaximalConesAllGfmDict = load("PolyMaximalConesAllGfmDict.sobj")

# We record the one we need:
PolyMaximalConesGfmDict = PolyMaximalConesAllGfmDict[2]


###########################################################################
# Compute the intersection of Cell with the Grobner fan of the projection #
###########################################################################

SubdivisionsNewCell= computeSubdivisionsOfTypeConeByGrobnerFan(newCell,PolyMaximalConesGfmDict)


# We record the output:
# SubdivisionsNewCell
# ([0, 1, 2, 4, 5, 6, 8, 9, 10, 11],
#  [A 6-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 5 rays, 1 line,
#   A 6-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 5 rays, 1 line,
#   A 6-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 6 rays, 1 line,
#   A 6-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 6 rays, 1 line,
#   A 6-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 5 rays, 1 line,
#   A 6-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 6 rays, 1 line,
#   A 6-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 7 rays, 1 line,
#   A 6-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 5 rays, 1 line,
#   A 6-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 7 rays, 1 line,
#   A 6-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 5 rays, 1 line])


# We compute the pieces of the subdivision and sample points to compute the leading terms:

PiecesNewCell = findRaysPiecesSamplePoint(SubdivisionsNewCell[1])

# We record the output:
# PiecesNewCell
# ({0: [[0, 0, 0, 0, 10, -17],
#    [0, 0, -27, 0, 2, 2],
#    [0, 0, 0, 0, 1, 1],
#    [27, 0, -27, -27, 29, -25],
#    [27, 0, 0, 0, 29, 2]],
#   1: [[-2, -2, -29, -2, 0, 0],
#    [17, 17, 17, 17, 0, 27],
#    [5, 5, -22, 5, 0, 0],
#    [22, -5, -5, -5, 0, 0],
#    [10, 1, -17, -8, 0, 0]],
#   2: [[-2, -2, -29, -2, 0, 0],
#    [-1, -1, -1, -1, 0, 0],
#    [17, 17, 17, 17, 0, 27],
#    [25, -2, -29, -29, 0, 0],
#    [10, 1, -17, -8, 0, 0],
#    [22, -5, -5, -5, 0, 0]],
#   3: [[27, 0, 0, 0, 5, 5],
#    [0, 0, -27, 0, -5, -5],
#    [0, 0, 0, 0, -1, -1],
#    [27, 0, -27, -27, -5, -5],
#    [9, 0, -18, -9, -1, -1],
#    [0, 0, 0, 0, -17, 10]],
#   4: [[27, 0, 0, 0, 5, 5],
#    [0, 0, 0, 0, -17, 10],
#    [27, 0, -27, -27, -5, -5],
#    [27, 0, -27, -27, 2, 2],
#    [9, 0, -18, -9, -1, -1]],
#   5: [[-2, -2, -29, -2, 0, 0],
#    [-10, -10, -10, -10, 0, -27],
#    [-2, -29, -56, -56, 0, -54],
#    [22, -5, -5, -5, 0, 0],
#    [5, 5, -22, 5, 0, 0],
#    [-2, -29, -29, -29, 0, -27]],
#   6: [[27, 0, -27, -27, 29, -25],
#    [0, 0, 0, 0, 10, -17],
#    [0, 0, -27, 0, -5, -5],
#    [27, 0, -27, -27, -5, -5],
#    [0, 0, 0, 0, -1, -1],
#    [27, 0, 0, 0, 5, 5],
#    [9, 0, -18, -9, -1, -1]],
#   7: [[-2, -29, -56, -56, 0, -54],
#    [22, -5, -5, -5, 0, 0],
#    [32, 5, -22, -22, 0, 0],
#    [25, -2, -29, -29, 0, 0],
#    [10, 1, -17, -8, 0, 0]],
#   8: [[-2, -2, -29, -2, 0, 0],
#    [-2, -29, -56, -56, 0, -54],
#    [-1, -1, -1, -1, 0, 0],
#    [10, 1, -17, -8, 0, 0],
#    [25, -2, -29, -29, 0, 0],
#    [22, -5, -5, -5, 0, 0],
#    [-2, -29, -29, -29, 0, -27]],
#   9: [[-2, -29, -56, -56, 0, -54],
#    [-2, -2, -29, -2, 0, 0],
#    [5, 5, -22, 5, 0, 0],
#    [22, -5, -5, -5, 0, 0],
#    [10, 1, -17, -8, 0, 0]]},
#  {0: A 6-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 5 rays, 1 line,
#   1: A 6-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 5 rays, 1 line,
#   2: A 6-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 6 rays, 1 line,
#   3: A 6-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 6 rays, 1 line,
#   4: A 6-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 5 rays, 1 line,
#   5: A 6-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 6 rays, 1 line,
#   6: A 6-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 7 rays, 1 line,
#   7: A 6-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 5 rays, 1 line,
#   8: A 6-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 7 rays, 1 line,
#   9: A 6-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 5 rays, 1 line},
#  {0: [108, 0, -108, -54, 142, -74],
#   1: [104, 32, -112, 14, 0, 54],
#   2: [142, 16, -128, -56, 0, 54],
#   3: [126, 0, -144, -72, -48, 6],
#   4: [180, 0, -144, -126, -32, 22],
#   5: [22, -140, -302, -194, 0, -216],
#   6: [180, 0, -198, -126, 64, -98],
#   7: [174, -60, -258, -240, 0, -108],
#   8: [100, -134, -332, -260, 0, -162],
#   9: [66, -60, -258, -132, 0, -108]})

# We check the lineality space is always the all ones vector:
# set([tuple(PiecesNewCell[-2][k].lines()[0].vector()) for k in PiecesNewCell[-2].keys()])
# {(1, 1, 1, 1, 1, 1)}

# We record the sample points to compute the leading terms:

allWeightsMxlCell = PiecesNewCell[-1]


###########################
# Projection of Polytopes #
###########################

# We compute the projection away from x,y for all the chambers.

projectedChambers= {k: projectPolyhedra(SubdivisionsNewCell[1][k]) for k in range(len(SubdivisionsNewCell[1]))}

noRepetedProjectedChambers = list(set(projectedChambers.values()))

projectedSubdivisionsNewCell = (range(len(noRepetedProjectedChambers)), noRepetedProjectedChambers)

len(projectedSubdivisionsNewCell[1])
3

# # We verify the identifications of chambers with the desired projections
# [k for k in projectedChambers.keys() if projectedChambers[k] == noRepetedProjectedChambers[0]]
# [4,7]
# [k for k in projectedChambers.keys() if projectedChambers[k] == noRepetedProjectedChambers[1]]
# [1]
# [k for k in projectedChambers.keys() if projectedChambers[k] == noRepetedProjectedChambers[2]]
# [0, 2, 3, 5, 6, 8, 9]


# There are overlaps between the pieces of the subdivision, so we must compute the overlaps and subdivide accordingly. Since there are 4 pieces, we can do this by hand.

# We first check that the last piece is the whole Cell
# Cell == projectedSubdivisionsNewCell[1][2]
#True

P0 = projectedSubdivisionsNewCell[1][0]
P1 = projectedSubdivisionsNewCell[1][1]

# The two pieces intersect in a common face:
# P0.intersection(P1).dim()
# 3


trueSubdivision = [[0,1],[P0,P1]]


# We compute the pieces of the subdivision and sample points to compute the leading terms:

PiecesprojectedSubdivisionsNewCell = findRaysPiecesSamplePoint(trueSubdivision[1])

# # We record the output
# PiecesprojectedSubdivisionsNewCell
# ({0: [[2, 1, -1, 0], [2, 1, 0, 0], [1, 0, 0, 0]],
#   1: [[1, 0, 0, 0], [0, 0, -1, 0], [2, 1, -1, 0]]},
#  {0: A 4-dimensional polyhedron in QQ^4 defined as the convex hull of 1 vertex, 3 rays, 1 line,
#   1: A 4-dimensional polyhedron in QQ^4 defined as the convex hull of 1 vertex, 3 rays, 1 line},
#  {0: [10, 4, -2, 0], 1: [6, 2, -4, 0]})


# # We record the sample points to compute the leading terms:
# PiecesprojectedSubdivisionsNewCell[-1]
# {0: [10, 4, -2, 0], 1: [6, 2, -4, 0]}

allWeightsProjectedChambers = PiecesprojectedSubdivisionsNewCell[-1]


###########################
# Lower dimensional Cones #
###########################

newCellFacets = computeFacets(trueSubdivision)

# # We record the output
# newCellFacets
# ([(0, 1)],
#  [A 3-dimensional polyhedron in QQ^4 defined as the convex hull of 1 vertex, 2 rays, 1 line])


# We compute the pieces of the newSubdivision and sample points to compute the leading terms:

PiecesNewCellFacets = findRaysPiecesSamplePoint(newCellFacets[1])

# We record the output
# PiecesNewCellFacets
# ({0: [[0, -1, -1, -1], [0, -1, -3, -2]]},
#  {0: A 3-dimensional polyhedron in QQ^4 defined as the convex hull of 1 vertex, 2 rays, 1 line},
#  {0: [0, -4, -8, -6]})

# We record the sample points:

AllWeightsProjectedFacets = PiecesNewCellFacets[-1]

# The rays will be in a facet of Cell2, so we need not analyze them now.

###################################
# Simplify Weight vectors to Test #
###################################

allWeights = allWeightsProjectedChambers.values() + AllWeightsProjectedFacets.values()

# We compute primitive vectors with non-positive coefficients equivalent to each one of the sample vectors above, by substracting appropriate multiplies of the all-ones vector  and taking a primitive vector thereafter. This is implemented in the function "makeNegativeAndPrimitive"

allWeightsSimplified = []
for k in range(len(allWeights)):
    allWeightsSimplified.append(makeNegativeAndPrimitive(allWeights[k]))

# # We record the output vectors: we will use these to compute examples with Singular
# allWeightsSimplified
# [[0, -3, -6, -5],
#  [0, -2, -5, -3],
#  [0, -2, -4, -3]]


#############################
# H-representation of Cells #
#############################

# We record the H-representation of all the pieces of the subdivision (for all dimensions) lying in the relative interior of the cell)

{k: PiecesprojectedSubdivisionsNewCell[1][k].Hrepresentation() for k in PiecesprojectedSubdivisionsNewCell[1].keys()}
# {0: (An inequality (0, 1, 1, -2) x + 0 >= 0,
#   An inequality (0, 0, -1, 1) x + 0 >= 0,
#   An inequality (1, -2, 0, 1) x + 0 >= 0),
#  1: (An inequality (0, 1, 0, -1) x + 0 >= 0,
#   An inequality (1, -2, 0, 1) x + 0 >= 0,
#   An inequality (0, -1, -1, 2) x + 0 >= 0)}

{k: PiecesNewCellFacets[1][k].Hrepresentation() for k in PiecesNewCellFacets[1].keys()}
# {0: (An equation (0, 1, 1, -2) x + 0 == 0,
#   An inequality (1, 0, 2, -3) x + 0 >= 0,
#   An inequality (0, 0, -1, 1) x + 0 >= 0)}
















