##################################################
# Calculations of all Newton Subdivisions Cell 6 #
##################################################

# We use the calculations of the 8 subdivisions of the TypeIICone done in "ComputingSubdivisionsCoefficientsyz.sage" in order to compute the possible Newton Subdivisions for the yz-projection on each of the 8 cells. This will detect possible subdivisions of the original 8 cells of the TypeIICone.

# Once the chambers are computed, we project back to the first 4 coordinates. We compute the pieces and check for overlaps. After turning the collection into a decomposition of Cell0, we find the facets and rays. We only consider lower dimensional faces and sample points if they are in the relative interior of the original Cell, since otherwise these points will be taken care of when analyzing the corresponding cell in the boundary.

# The required functions are obtain by loading the following auxiliary file:
load("macroslocalJInvariantComputationsAndPrimesWithBadReduction.sage")

#########################################
# Generate the ambient ring and Weights #
#########################################

AXs = [var("b5"),var("b4"),var("b34"), var("b2"), var("x"), var("y")]
RX = PolynomialRing(QQ,AXs)
KX = FractionField(R);

Rxy = PolynomialRing(QQ, [var("x"), var("y")])

###########################
# Grobner Cones and Cells #
###########################

# We load the 9 cells the variables are As = [var("b5"),var("b4"),var("b34"), var("b2")]

allPiecesTypeIICone = load("allPiecesTypeIICone.sobj")

Cell = allPiecesTypeIICone[6]

# Cell.Hrepresentation()
# (An equation (0, 0, 1, -1) x + 0 == 0,
#  An inequality (1, -2, 0, 1) x + 0 >= 0,
#  An inequality (0, 1, 0, -1) x + 0 >= 0)

# Cell.lines()
# (A line in the direction (1, 1, 1, 1),)

# We compute the inequalities and equalities by re-embedding in AXS
ieqsCell = inequalitiesOfReembeddedPolyhedron(Cell)
eqnsCell = equationsOfReembeddedPolyhedron(Cell)

# ieqsCell
# [(0, 1, -2, 0, 1, 0, 0), (0, 0, 1, 0, -1, 0, 0)]
# eqnsCell
# [(0, 0, 0, 1, -1, 0, 0)]


# We re-embedd the Cell in R^6:

newCell = Polyhedron(ieqs=ieqsCell, eqns = eqnsCell)
#  newCell.Hrepresentation()
# (An equation (0, 0, 1, -1, 0, 0) x + 0 == 0,
#  An inequality (0, 1, -1, 0, 0, 0) x + 0 >= 0,
#  An inequality (1, -2, 1, 0, 0, 0) x + 0 >= 0)

# We load the Grobner fans and the Maximal Cones for all 9 cells:
allGfm =load("allGfmCells0to8.sobj")
PolyMaximalConesAllGfmDict = load("PolyMaximalConesAllGfmDict.sobj")

# We record the one we need:
PolyMaximalConesGfmDict = PolyMaximalConesAllGfmDict[6]


###########################################################################
# Compute the intersection of Cell with the Grobner fan of the projection #
###########################################################################

SubdivisionsNewCell= computeSubdivisionsOfTypeConeByGrobnerFan(newCell,PolyMaximalConesGfmDict)


# We record the output:
# SubdivisionsNewCell
# ([0, 1, 4, 6, 7, 8, 9, 10, 11, 13],
#  [A 5-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 4 rays, 1 line,
#   A 5-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 4 rays, 1 line,
#   A 5-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 4 rays, 1 line,
#   A 5-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 4 rays, 1 line,
#   A 5-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 4 rays, 1 line,
#   A 5-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 5 rays, 1 line,
#   A 5-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 4 rays, 1 line,
#   A 5-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 4 rays, 1 line,
#   A 5-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 4 rays, 1 line,
#   A 5-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 5 rays, 1 line])


# We compute the pieces of the subdivision and sample points to compute the leading terms:

PiecesNewCell = findRaysPiecesSamplePoint(SubdivisionsNewCell[1])
	      
# We record the output:
# PiecesNewCell
# ({0: [[27, 0, 0, 0, 5, 5],
#    [0, 0, 0, 0, -17, 10],
#    [0, 0, 0, 0, -1, -1],
#    [27, 0, -27, -27, -5, -5]],
#   1: [[0, 0, 0, 0, 1, 1],
#    [0, 0, 0, 0, 10, -17],
#    [27, 0, -27, -27, 29, -25],
#    [27, 0, 0, 0, 29, 2]],
#   2: [[0, 0, 0, 0, 1, 1],
#    [27, 0, -27, -27, 29, -25],
#    [0, 0, 0, 0, 10, -17],
#    [27, 0, 0, 0, 29, 2]],
#   3: [[27, 0, 0, 0, 5, 5],
#    [0, 0, 0, 0, -17, 10],
#    [27, 0, -27, -27, -5, -5],
#    [27, 0, -27, -27, 2, 2]],
#   4: [[-1, -1, -1, -1, 0, 0],
#    [-10, -10, -10, -10, -27, 0],
#    [25, -2, -29, -29, 0, 0],
#    [22, -5, -5, -5, 0, 0]],
#   5: [[27, 0, -27, -27, 29, -25],
#    [0, 0, 0, 0, 10, -17],
#    [27, 0, 0, 0, 5, 5],
#    [27, 0, -27, -27, -5, -5],
#    [0, 0, 0, 0, -1, -1]],
#   6: [[52, 25, -2, -2, 54, 0],
#    [17, 17, 17, 17, 27, 0],
#    [22, -5, -5, -5, 0, 0],
#    [25, -2, -2, -2, 27, 0]],
#   7: [[52, 25, -2, -2, 54, 0],
#    [17, 17, 17, 17, 27, 0],
#    [22, -5, -5, -5, 0, 0],
#    [25, -2, -2, -2, 27, 0]],
#   8: [[52, 25, -2, -2, 54, 0],
#    [22, -5, -5, -5, 0, 0],
#    [32, 5, -22, -22, 0, 0],
#    [25, -2, -29, -29, 0, 0]],
#   9: [[27, 0, -27, -27, 29, -25],
#    [0, 0, 0, 0, 1, 1],
#    [27, 0, 0, 0, 29, 2],
#    [27, 0, 0, 0, 5, 5],
#    [27, 0, -27, -27, 2, 2]]},
#  {0: A 5-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 4 rays, 1 line,
#   1: A 5-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 4 rays, 1 line,
#   2: A 5-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 4 rays, 1 line,
#   3: A 5-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 4 rays, 1 line,
#   4: A 5-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 4 rays, 1 line,
#   5: A 5-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 5 rays, 1 line,
#   6: A 5-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 4 rays, 1 line,
#   7: A 5-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 4 rays, 1 line,
#   8: A 5-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 4 rays, 1 line,
#   9: A 5-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex, 5 rays, 1 line},
#  {0: [108, 0, -54, -54, -36, 18],
#   1: [108, 0, -54, -54, 138, -78],
#   2: [108, 0, -54, -54, 138, -78],
#   3: [162, 0, -108, -108, -30, 24],
#   4: [72, -36, -90, -90, -54, 0],
#   5: [162, 0, -108, -108, 76, -86],
#   6: [232, 70, 16, 16, 216, 0],
#   7: [232, 70, 16, 16, 216, 0],
#   8: [262, 46, -116, -116, 108, 0],
#   9: [216, 0, -108, -108, 132, -30]})

# We check the lineality space is always the all ones vector:
# set([tuple(PiecesNewCell[-2][k].lines()[0].vector()) for k in PiecesNewCell[-2].keys()])
# {(1, 1, 1, 1, 1, 1)}

# We record the sample points to compute the leading terms:

allWeightsMxlCell = PiecesNewCell[-1]


###########################
# Projection of Polytopes #
###########################

# We compute the projection away from x,y for all the chambers.

projectedChambers= {k: projectPolyhedra(SubdivisionsNewCell[1][k]) for k in range(len(SubdivisionsNewCell[1]))}

noRepetedProjectedChambers = list(set(projectedChambers.values()))

projectedSubdivisionsNewCell = (range(len(noRepetedProjectedChambers)), noRepetedProjectedChambers)

len(projectedSubdivisionsNewCell[1])
1

# We check that all polytopes project to the Cell. Therefore, there is only one possible subdivision!

# Cell == projectedSubdivisionsNewCell[1][0]
# True


trueSubdivision = [[0],[Cell]]


# We compute the pieces of the subdivision and sample points to compute the leading terms:

PiecesprojectedSubdivisionsNewCell = findRaysPiecesSamplePoint(trueSubdivision[1])

# # We record the output
# PiecesprojectedSubdivisionsNewCell
# ({0: [[2, 1, 0, 0], [1, 0, 0, 0]]},
#  {0: A 3-dimensional polyhedron in QQ^4 defined as the convex hull of 1 vertex, 2 rays, 1 line},
#  {0: [6, 2, 0, 0]})

# # We record the sample points to compute the leading terms:
# PiecesprojectedSubdivisionsNewCell[-1]
# {0: [6, 2, 0, 0]})

allWeightsProjectedChambers = PiecesprojectedSubdivisionsNewCell[-1]


###########################
# Lower dimensional Cones #
###########################

# There are none.


###################################
# Simplify Weight vectors to Test #
###################################

allWeights = allWeightsProjectedChambers.values() 

# We compute primitive vectors with non-positive coefficients equivalent to each one of the sample vectors above, by substracting appropriate multiplies of the all-ones vector  and taking a primitive vector thereafter. This is implemented in the function "makeNegativeAndPrimitive"

allWeightsSimplified = []
for k in range(len(allWeights)):
    allWeightsSimplified.append(makeNegativeAndPrimitive(allWeights[k]))

# # We record the output vectors: we will use these to compute examples with Singular
# allWeightsSimplified
# [[0, -2, -3, -3]]

#############################
# H-representation of Cells #
#############################

# We record the H-representation of all the pieces of the subdivision (for all dimensions) lying in the relative interior of the cell)

{k: PiecesprojectedSubdivisionsNewCell[1][k].Hrepresentation() for k in PiecesprojectedSubdivisionsNewCell[1].keys()}
# {0: (An equation (0, 0, 1, -1) x + 0 == 0,
#   An inequality (0, 1, -1, 0) x + 0 >= 0,
#   An inequality (1, -2, 1, 0) x + 0 >= 0)}












