##################################################
# Calculations of all Newton Subdivisions Cell 0 #
##################################################

# We use the calculations of the 8 subdivisions of the TypeIICone done in "ComputingSubdivisionsCoefficientsyz.sage" in order to compute the possible Newton Subdivisions for the yz-projection on each of the 8 cells. This will detect possible subdivisions of the original 8 cells of the TypeIICone.

# The required functions are obtain by loading the following auxiliary file:
load("macroslocalJInvariantComputationsAndPrimesWithBadReduction.sage")

#########################################
# Generate the ambient ring and Weights #
#########################################

AXs = [var("b5"),var("b4"),var("b34"), var("b2"), var("x"), var("y")]
RX = PolynomialRing(QQ,AXs)
KX = FractionField(R);

Rxy = PolynomialRing(QQ, [var("x"), var("y")])

###########################
# Grobner Cones and Cells #
###########################

# We load the 9 cells the variables are As = [var("b5"),var("b4"),var("b34"), var("b2")]

allPiecesTypeIICone = load("allPiecesTypeIICone.sobj")

Cell = allPiecesTypeIICone[0]

# Cell.Hrepresentation()
# (An inequality (1, -1, 0, 0) x + 0 >= 0,
#  An inequality (0, 0, -1, 1) x + 0 >= 0,
#  An inequality (-1, 2, 0, -1) x + 0 >= 0)
# Cell.lines()
# (A line in the direction (1, 1, 1, 1),)

# We compute the inequalities by re-embedding in AXS
ieqsCell = inequalitiesOfReembeddedPolyhedron(Cell)
# ieqsCell
# [(0, 1, -1, 0, 0, 0, 0), (0, 0, 0, -1, 1, 0, 0), (0, -1, 2, 0, -1, 0, 0)]


# We load the Grobner fans and the Maximal Cones for all 9 cells:
allGfm =load("allGfmCells0to8.sobj")
PolyMaximalConesAllGfmDict = load("PolyMaximalConesAllGfmDict.sobj")

# We record the one we need:
PolyMaximalConesGfmDict = PolyMaximalConesAllGfmDict[0]

#################################
# Maximizing monomials per cell #
#################################

# We take the known  "vertices" of the projection and compute the induced subdivisions. For this we take the H_representation of the cell, extend with 2 coordinates 0, 0 and add the equations corresponding to the x- and y-coordinates of each vertex:

# vertex1 = [2*b2, 2*b2+2*b4+ b5, 2*b2+ 2*b4 + b5]
# vertex2 = [2*b4, 4*b4+2*b5, 4*b4+2*b5]
# vertex4 = [2*b5, 5*b5, 5*b5]
# vertex12 = [b4+b5, b5 + 3*b4, b5 + 2*b4+2*b2]
# vertex24 = [2*b4, b5+4*b4, 6*b4-b5]
diagEq = (0,0,0,0,0, 1, -1)
vertexEqs = [[diagEq, (0, 1, 2, 0, 2, -1,0)], [diagEq, (0, 2, 4, 0, 0, -1, 0)], [diagEq, (0, 5, 0, 0, 0, -1, 0)] , [(0, 1, 3,0, 0, -1,0), (0, 1, 2, 0, 2, 0, -1)]  , [(0, 1, 4, 0, 0, -1, 0), (0, -1, 6, 0, 0, 0, -1)]]

newCells = {}
for i in range(len(vertexEqs)):
    print str(i)
    newCells[i] = Polyhedron(ieqs=ieqsCell, eqns = vertexEqs[i])


###############################
# Computation of subdivisions #
###############################

# Our calculations are valid when the residue field has characteristic 0.

allSubdivisions = {}
for i in range(len(vertexEqs)):
    print str(i)
    allSubdivisions[i]= computeSubdivisionsOfTypeConeByGrobnerFan(newCells[i],PolyMaximalConesGfmDict)

# # We record the output
# allSubdivisions[0]
# ([1, 2, 3, 4, 8, 9, 10, 11],
#  [A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 6 rays,
#   A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 6 rays,
#   A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 6 rays,
#   A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 4 rays,
#   A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 6 rays,
#   A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 6 rays,
#   A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 6 rays,
#   A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 4 rays])

# We compute the pieces of the subdivision and sample points to compute the leading terms:

PiecesCellTypeIICone = {}
for i in range(len(vertexEqs)):
    print str(i)
    PiecesCellTypeIICone[i] = findRaysPiecesSamplePoint(allSubdivisions[i][1])

# We record the output:
# PiecesCellTypeIICone
# {0: ({0: [[17, 17, -19, -19, 13, 13],
#     [23, 23, -85, -31, 7, 7],
#     [11, 2, -16, -7, 1, 1],
#     [137, 29, -79, -79, 37, 37],
#     [11, 11, -16, -16, 1, 1],
#     [65, 11, -43, -43, 1, 1]],
#    1: [[23, 23, -85, -31, 7, 7],
#     [-5, -5, -113, -5, -25, -25],
#     [11, 11, -16, -16, 1, 1],
#     [65, 11, -43, -43, 1, 1],
#     [11, 2, -16, -7, 1, 1],
#     [-1, -1, -1, -1, -5, -5]],
#    2: [[1, 1, -53, 1, 5, 5],
#     [1, 1, 1, 1, 5, 5],
#     [23, 23, -85, -31, 7, 7],
#     [17, 17, -19, -19, 13, 13],
#     [11, 2, -16, -7, 1, 1],
#     [137, 29, -79, -79, 37, 37]],
#    3: [[1, 1, -53, 1, 5, 5],
#     [-5, -5, -113, -5, -25, -25],
#     [11, 2, -16, -7, 1, 1],
#     [23, 23, -85, -31, 7, 7]],
#    4: [[17, 17, -19, -19, 13, 13],
#     [23, 23, -85, -31, 7, 7],
#     [11, 2, -16, -7, 1, 1],
#     [137, 29, -79, -79, 37, 37],
#     [11, 11, -16, -16, 1, 1],
#     [65, 11, -43, -43, 1, 1]],
#    5: [[23, 23, -85, -31, 7, 7],
#     [-5, -5, -113, -5, -25, -25],
#     [65, 11, -43, -43, 1, 1],
#     [11, 2, -16, -7, 1, 1],
#     [11, 11, -16, -16, 1, 1],
#     [-1, -1, -1, -1, -5, -5]],
#    6: [[1, 1, -53, 1, 5, 5],
#     [1, 1, 1, 1, 5, 5],
#     [23, 23, -85, -31, 7, 7],
#     [17, 17, -19, -19, 13, 13],
#     [11, 2, -16, -7, 1, 1],
#     [137, 29, -79, -79, 37, 37]],
#    7: [[1, 1, -53, 1, 5, 5],
#     [-5, -5, -113, -5, -25, -25],
#     [11, 2, -16, -7, 1, 1],
#     [23, 23, -85, -31, 7, 7]]},
#   {0: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 6 rays,
#    1: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 6 rays,
#    2: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 6 rays,
#    3: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 4 rays,
#    4: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 6 rays,
#    5: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 6 rays,
#    6: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 6 rays,
#    7: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 4 rays},
#   {0: [528, 186, -516, -390, 120, 120],
#    1: [208, 82, -548, -206, -40, -40],
#    2: [380, 146, -502, -268, 136, 136],
#    3: [60, 42, -534, -84, -24, -24],
#    4: [528, 186, -516, -390, 120, 120],
#    5: [208, 82, -548, -206, -40, -40],
#    6: [380, 146, -502, -268, 136, 136],
#    7: [60, 42, -534, -84, -24, -24]}),
#  1: ({0: [[-1, -1, -46, -46, -6, -6],
#     [-8, -8, -278, -143, -48, -48],
#     [26, -19, -109, -64, -24, -24],
#     [83, -52, -187, -187, -42, -42],
#     [-2, -2, -29, -29, -12, -12],
#     [76, -59, -194, -194, -84, -84]],
#    1: [[-8, -8, -278, -143, -48, -48],
#     [-1, -1, -28, -1, -6, -6],
#     [-2, -2, -29, -29, -12, -12],
#     [76, -59, -194, -194, -84, -84],
#     [26, -19, -109, -64, -24, -24],
#     [-1, -1, -1, -1, -6, -6]],
#    2: [[2, 2, -133, 2, 12, 12],
#     [1, 1, 1, 1, 6, 6],
#     [-8, -8, -278, -143, -48, -48],
#     [-1, -1, -46, -46, -6, -6],
#     [26, -19, -109, -64, -24, -24],
#     [83, -52, -187, -187, -42, -42]],
#    3: [[2, 2, -133, 2, 12, 12],
#     [-1, -1, -28, -1, -6, -6],
#     [26, -19, -109, -64, -24, -24],
#     [-8, -8, -278, -143, -48, -48]],
#    4: [[-1, -1, -46, -46, -6, -6],
#     [-8, -8, -278, -143, -48, -48],
#     [26, -19, -109, -64, -24, -24],
#     [83, -52, -187, -187, -42, -42],
#     [-2, -2, -29, -29, -12, -12],
#     [76, -59, -194, -194, -84, -84]],
#    5: [[-8, -8, -278, -143, -48, -48],
#     [-1, -1, -28, -1, -6, -6],
#     [76, -59, -194, -194, -84, -84],
#     [26, -19, -109, -64, -24, -24],
#     [-2, -2, -29, -29, -12, -12],
#     [-1, -1, -1, -1, -6, -6]],
#    6: [[2, 2, -133, 2, 12, 12],
#     [1, 1, 1, 1, 6, 6],
#     [-8, -8, -278, -143, -48, -48],
#     [-1, -1, -46, -46, -6, -6],
#     [26, -19, -109, -64, -24, -24],
#     [83, -52, -187, -187, -42, -42]],
#    7: [[2, 2, -133, 2, 12, 12],
#     [-1, -1, -28, -1, -6, -6],
#     [26, -19, -109, -64, -24, -24],
#     [-8, -8, -278, -143, -48, -48]]},
#   {0: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 6 rays,
#    1: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 6 rays,
#    2: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 6 rays,
#    3: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 4 rays,
#    4: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 6 rays,
#    5: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 6 rays,
#    6: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 6 rays,
#    7: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 4 rays},
#   {0: [348, -282, -1686, -1326, -432, -432],
#    1: [180, -180, -1278, -864, -360, -360],
#    2: [206, -154, -1504, -874, -204, -204],
#    3: [38, -52, -1096, -412, -132, -132],
#    4: [348, -282, -1686, -1326, -432, -432],
#    5: [180, -180, -1278, -864, -360, -360],
#    6: [206, -154, -1504, -874, -204, -204],
#    7: [38, -52, -1096, -412, -132, -132]}),
#  2: ({0: [[-1, -1, -37, -37, -5, -5],
#     [-2, -2, -56, -29, -10, -10],
#     [-5, -23, -59, -41, -25, -25],
#     [-25, -133, -241, -241, -125, -125],
#     [-5, -5, -59, -59, -25, -25],
#     [-8, -35, -62, -62, -40, -40]],
#    1: [[-2, -2, -56, -29, -10, -10],
#     [-5, -5, -113, -5, -25, -25],
#     [-5, -5, -59, -59, -25, -25],
#     [-8, -35, -62, -62, -40, -40],
#     [-5, -23, -59, -41, -25, -25],
#     [-1, -1, -1, -1, -5, -5]],
#    2: [[1, 1, -53, 1, 5, 5],
#     [1, 1, 1, 1, 5, 5],
#     [-2, -2, -56, -29, -10, -10],
#     [-1, -1, -37, -37, -5, -5],
#     [-5, -23, -59, -41, -25, -25],
#     [-25, -133, -241, -241, -125, -125]],
#    3: [[1, 1, -53, 1, 5, 5],
#     [-5, -5, -113, -5, -25, -25],
#     [-5, -23, -59, -41, -25, -25],
#     [-2, -2, -56, -29, -10, -10]],
#    4: [[-1, -1, -37, -37, -5, -5],
#     [-2, -2, -56, -29, -10, -10],
#     [-5, -23, -59, -41, -25, -25],
#     [-25, -133, -241, -241, -125, -125],
#     [-5, -5, -59, -59, -25, -25],
#     [-8, -35, -62, -62, -40, -40]],
#    5: [[-2, -2, -56, -29, -10, -10],
#     [-5, -5, -113, -5, -25, -25],
#     [-8, -35, -62, -62, -40, -40],
#     [-5, -23, -59, -41, -25, -25],
#     [-5, -5, -59, -59, -25, -25],
#     [-1, -1, -1, -1, -5, -5]],
#    6: [[1, 1, -53, 1, 5, 5],
#     [1, 1, 1, 1, 5, 5],
#     [-2, -2, -56, -29, -10, -10],
#     [-1, -1, -37, -37, -5, -5],
#     [-5, -23, -59, -41, -25, -25],
#     [-25, -133, -241, -241, -125, -125]],
#    7: [[1, 1, -53, 1, 5, 5],
#     [-5, -5, -113, -5, -25, -25],
#     [-5, -23, -59, -41, -25, -25],
#     [-2, -2, -56, -29, -10, -10]]},
#   {0: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 6 rays,
#    1: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 6 rays,
#    2: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 6 rays,
#    3: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 4 rays,
#    4: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 6 rays,
#    5: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 6 rays,
#    6: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 6 rays,
#    7: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 4 rays},
#   {0: [-92, -398, -1028, -938, -460, -460],
#    1: [-52, -142, -700, -394, -260, -260],
#    2: [-62, -314, -890, -692, -310, -310],
#    3: [-22, -58, -562, -148, -110, -110],
#    4: [-92, -398, -1028, -938, -460, -460],
#    5: [-52, -142, -700, -394, -260, -260],
#    6: [-62, -314, -890, -692, -310, -310],
#    7: [-22, -58, -562, -148, -110, -110]}),
#  3: ({0: [[2, 2, -85, 1, 8, 8],
#     [2, 2, 1, 1, 8, 8],
#     [3, 2, 1, 1, 9, 9],
#     [1, 1, -48, 1, 4, 5],
#     [3, 2, -96, 1, 9, 9],
#     [1, 1, 1, 1, 4, 5]],
#    1: [[0, 0, -1, 0, 0, 0],
#     [2, 2, -85, 1, 8, 8],
#     [1, 1, -48, 1, 4, 5],
#     [3, 2, -96, 1, 9, 9]],
#    2: [[2, 2, -85, 1, 8, 8],
#     [2, 2, 1, 1, 8, 8],
#     [169, 4, -163, -163, 181, -149],
#     [38, 1, -37, -37, 41, -34],
#     [87, 2, -85, -84, 93, -77],
#     [12, 12, -37, -37, 48, -38]],
#    3: [[-5, -5, -96, -5, -20, -25],
#     [0, 0, -1, 0, 0, 0],
#     [5, 0, -7, -5, 5, -5],
#     [17, 17, -74, -74, 68, -97],
#     [12, 12, -37, -37, 48, -38],
#     [38, 1, -37, -37, 41, -34],
#     [2, 2, -85, 1, 8, 8],
#     [87, 2, -85, -84, 93, -77]],
#    4: [[50, 1, -48, -48, 53, -44],
#     [193, 4, -185, -185, 205, -169],
#     [99, 2, -96, -95, 105, -87],
#     [87, 2, -85, -84, 93, -77],
#     [169, 4, -163, -163, 181, -149],
#     [38, 1, -37, -37, 41, -34]],
#    5: [[-1, -1, -1, -1, -4, -5],
#     [50, 1, -48, -48, 53, -44],
#     [99, 2, -96, -95, 105, -87],
#     [5, 0, -7, -5, 5, -5],
#     [87, 2, -85, -84, 93, -77],
#     [38, 1, -37, -37, 41, -34],
#     [-5, -5, -96, -5, -20, -25],
#     [17, 17, -74, -74, 68, -97]],
#    6: [[2, 2, -85, 1, 8, 8],
#     [2, 2, 1, 1, 8, 8],
#     [3, 2, 1, 1, 9, 9],
#     [3, 2, -96, 1, 9, 9],
#     [193, 4, -185, -185, 205, -169],
#     [99, 2, -96, -95, 105, -87],
#     [87, 2, -85, -84, 93, -77],
#     [169, 4, -163, -163, 181, -149]],
#    7: [[0, 0, -1, 0, 0, 0],
#     [5, 0, -7, -5, 5, -5],
#     [99, 2, -96, -95, 105, -87],
#     [87, 2, -85, -84, 93, -77],
#     [2, 2, -85, 1, 8, 8],
#     [3, 2, -96, 1, 9, 9]]},
#   {0: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 6 rays,
#    1: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 4 rays,
#    2: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 6 rays,
#    3: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 8 rays,
#    4: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 6 rays,
#    5: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 8 rays,
#    6: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 8 rays,
#    7: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 6 rays},
#   {0: [24, 20, -452, 12, 84, 88],
#    1: [12, 10, -460, 6, 42, 44],
#    2: [620, 46, -812, -638, 758, -564],
#    3: [312, 58, -844, -482, 486, -536],
#    4: [1272, 28, -1228, -1224, 1356, -1120],
#    5: [580, 34, -888, -698, 682, -748],
#    6: [1116, 40, -1416, -1046, 1236, -896],
#    7: [392, 16, -740, -364, 440, -304]}),
#  4: ({0: [[1, 1, -53, 1, 5, 5],
#     [1, 1, 1, 1, 5, 5],
#     [-1, -1, -37, -37, -5, -5],
#     [-2, -2, -56, -29, -10, -10],
#     [55, 1, -53, -53, 59, -49]],
#    1: [[55, 1, -53, -53, 59, -49],
#     [1, 1, -53, 1, 5, 5],
#     [-2, -2, -56, -29, -10, -10],
#     [-5, -5, -113, -5, -25, -25]],
#    2: [[55, 1, -53, -53, 59, -49],
#     [-2, -2, -56, -29, -10, -10],
#     [-1, -1, -37, -37, -5, -5],
#     [-5, -5, -59, -59, -25, -25]],
#    3: [[55, 1, -53, -53, 59, -49],
#     [-2, -2, -56, -29, -10, -10],
#     [-5, -5, -113, -5, -25, -25],
#     [-1, -1, -1, -1, -5, -5],
#     [-5, -5, -59, -59, -25, -25]],
#    4: [[1, 1, -53, 1, 5, 5],
#     [1, 1, 1, 1, 5, 5],
#     [55, 1, -53, -53, 59, -49],
#     [-2, -2, -56, -29, -10, -10],
#     [-1, -1, -37, -37, -5, -5]],
#    5: [[55, 1, -53, -53, 59, -49],
#     [1, 1, -53, 1, 5, 5],
#     [-2, -2, -56, -29, -10, -10],
#     [-5, -5, -113, -5, -25, -25]]},
#   {0: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 5 rays,
#    1: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 4 rays,
#    2: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 4 rays,
#    3: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 5 rays,
#    4: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 5 rays,
#    5: A 4-dimensional polyhedron in QQ^6 defined as the convex hull of 1 vertex and 4 rays},
#   {0: [108, 0, -396, -234, 108, -108],
#    1: [98, -10, -550, -172, 58, -158],
#    2: [94, -14, -410, -356, 38, -178],
#    3: [84, -24, -564, -294, -12, -228],
#    4: [108, 0, -396, -234, 108, -108],
#    5: [98, -10, -550, -172, 58, -158]})}


# We record the sample points to compute the leading terms:

allWeightsCellMxl = {}
for i in range(len(vertexEqs)):
    print str(i)
    allWeightsCellMxl[i] =     PiecesCellTypeIICone[i][-1]

# # We record the output:
# allWeightsCellMxl
# {0: {0: [528, 186, -516, -390, 120, 120],
#   1: [208, 82, -548, -206, -40, -40],
#   2: [380, 146, -502, -268, 136, 136],
#   3: [60, 42, -534, -84, -24, -24],
#   4: [528, 186, -516, -390, 120, 120],
#   5: [208, 82, -548, -206, -40, -40],
#   6: [380, 146, -502, -268, 136, 136],
#   7: [60, 42, -534, -84, -24, -24]},
#  1: {0: [348, -282, -1686, -1326, -432, -432],
#   1: [180, -180, -1278, -864, -360, -360],
#   2: [206, -154, -1504, -874, -204, -204],
#   3: [38, -52, -1096, -412, -132, -132],
#   4: [348, -282, -1686, -1326, -432, -432],
#   5: [180, -180, -1278, -864, -360, -360],
#   6: [206, -154, -1504, -874, -204, -204],
#   7: [38, -52, -1096, -412, -132, -132]},
#  2: {0: [-92, -398, -1028, -938, -460, -460],
#   1: [-52, -142, -700, -394, -260, -260],
#   2: [-62, -314, -890, -692, -310, -310],
#   3: [-22, -58, -562, -148, -110, -110],
#   4: [-92, -398, -1028, -938, -460, -460],
#   5: [-52, -142, -700, -394, -260, -260],
#   6: [-62, -314, -890, -692, -310, -310],
#   7: [-22, -58, -562, -148, -110, -110]},
#  3: {0: [24, 20, -452, 12, 84, 88],
#   1: [12, 10, -460, 6, 42, 44],
#   2: [620, 46, -812, -638, 758, -564],
#   3: [312, 58, -844, -482, 486, -536],
#   4: [1272, 28, -1228, -1224, 1356, -1120],
#   5: [580, 34, -888, -698, 682, -748],
#   6: [1116, 40, -1416, -1046, 1236, -896],
#   7: [392, 16, -740, -364, 440, -304]},
#  4: {0: [108, 0, -396, -234, 108, -108],
#   1: [98, -10, -550, -172, 58, -158],
#   2: [94, -14, -410, -356, 38, -178],
#   3: [84, -24, -564, -294, -12, -228],
#   4: [108, 0, -396, -234, 108, -108],
#   5: [98, -10, -550, -172, 58, -158]}}

###########################
# Lower dimensional Cones #
###########################

allSubdivisions3 = {}
for i in range(len(vertexEqs)):
    print str(i)
    allSubdivisions3[i] = computeFacets(allSubdivisions[i])

PiecesCellTypeIICone3 = {}
for i in range(len(vertexEqs)):
    print str(i)
    PiecesCellTypeIICone3[i] = findRaysPiecesSamplePoint(allSubdivisions3[i][1])


allWeightsCellFacets = {}
for i in range(len(vertexEqs)):
    print str(i)
    allWeightsCellFacets[i]= PiecesCellTypeIICone3[i][-1]

# # We record the output
# allWeightsCellFacets
# {0: {0: [220, 94, -320, -194, 20, 20],
#   1: [70, 52, -308, -74, 26, 26],
#   2: [58, 40, -428, -86, -34, -34],
#   3: [70, 52, -308, -74, 26, 26],
#   4: [376, 142, -398, -272, 116, 116],
#   5: [220, 94, -320, -194, 20, 20],
#   6: [58, 40, -428, -86, -34, -34],
#   7: [220, 94, -320, -194, 20, 20],
#   8: [376, 142, -398, -272, 116, 116],
#   9: [376, 142, -398, -272, 116, 116],
#   10: [220, 94, -320, -194, 20, 20],
#   11: [70, 52, -308, -74, 26, 26],
#   12: [58, 40, -428, -86, -34, -34],
#   13: [70, 52, -308, -74, 26, 26],
#   14: [376, 142, -398, -272, 116, 116],
#   15: [58, 40, -428, -86, -34, -34]},
#  1: {0: [184, -176, -1220, -860, -336, -336],
#   1: [40, -50, -1040, -410, -120, -120],
#   2: [34, -56, -830, -416, -156, -156],
#   3: [40, -50, -1040, -410, -120, -120],
#   4: [200, -160, -1240, -880, -240, -240],
#   5: [184, -176, -1220, -860, -336, -336],
#   6: [34, -56, -830, -416, -156, -156],
#   7: [184, -176, -1220, -860, -336, -336],
#   8: [200, -160, -1240, -880, -240, -240],
#   9: [200, -160, -1240, -880, -240, -240],
#   10: [184, -176, -1220, -860, -336, -336],
#   11: [40, -50, -1040, -410, -120, -120],
#   12: [34, -56, -830, -416, -156, -156],
#   13: [40, -50, -1040, -410, -120, -120],
#   14: [200, -160, -1240, -880, -240, -240],
#   15: [34, -56, -830, -416, -156, -156]},
#  2: {0: [-40, -130, -472, -382, -200, -200],
#   1: [-12, -48, -336, -138, -60, -60],
#   2: [-24, -60, -456, -150, -120, -120],
#   3: [-12, -48, -336, -138, -60, -60],
#   4: [-66, -318, -786, -696, -330, -330],
#   5: [-40, -130, -472, -382, -200, -200],
#   6: [-24, -60, -456, -150, -120, -120],
#   7: [-40, -130, -472, -382, -200, -200],
#   8: [-66, -318, -786, -696, -330, -330],
#   9: [-66, -318, -786, -696, -330, -330],
#   10: [-40, -130, -472, -382, -200, -200],
#   11: [-12, -48, -336, -138, -60, -60],
#   12: [-24, -60, -456, -150, -120, -120],
#   13: [-12, -48, -336, -138, -60, -60],
#   14: [-66, -318, -786, -696, -330, -330],
#   15: [-24, -60, -456, -150, -120, -120]},
#  3: {0: [12, 10, -458, 6, 42, 44],
#   1: [520, 20, -664, -490, 580, -420],
#   2: [382, 16, -724, -354, 430, -294],
#   3: [1096, 24, -1058, -1054, 1168, -964],
#   4: [548, 12, -532, -528, 584, -484],
#   5: [382, 8, -376, -368, 406, -338],
#   6: [20, 16, -358, 8, 68, 68],
#   7: [278, 34, -488, -314, 380, -282],
#   8: [10, 8, -364, 4, 34, 34],
#   9: [188, 8, -356, -176, 212, -148],
#   10: [588, 14, -570, -568, 630, -520],
#   11: [284, 30, -598, -410, 374, -476]},
#  4: {0: [108, 0, -324, -162, 108, -108],
#   1: [96, -12, -444, -174, 48, -168],
#   2: [108, 0, -324, -162, 108, -108],
#   3: [108, 0, -324, -162, 108, -108],
#   4: [104, -4, -292, -238, 88, -128],
#   5: [96, -12, -336, -282, 48, -168],
#   6: [108, 0, -324, -162, 108, -108],
#   7: [104, -4, -292, -238, 88, -128],
#   8: [96, -12, -444, -174, 48, -168]}}


########
# Rays #
########

# We consider all the rays 
allRays = {}
for i in range(len(vertexEqs)):
    allRays[i]=[]
    for r in PiecesCellTypeIICone3[i][0].keys():
    	for x in PiecesCellTypeIICone3[i][0][r]:
	    if x in allRays[i]:
	       print 'already Counted'
	    else:
		allRays[i].append(x)

# [len(x) for x in allRays.values()]
# [8, 8, 8, 16, 6]

# Discard the ones in the boundary of ThetaIICone:
relInteriorRays = {}
for i in range(len(vertexEqs)):
    relInteriorRays[i] = []
    for r in allRays[i]:
        if r[1] != r[2]:
    	   if r[1] != r[3]:
       	     if r[0] != r[1]:
	       relInteriorRays[i].append(r)	     

# [len(x) for x in relInteriorRays.values()]
# [3, 3, 3, 9, 1]

allWeightsCellRays = {}
for i in range(len(vertexEqs)):
    print str(i)
    allWeightsCellRays[i]= {k: relInteriorRays[i][k] for k in range(len(relInteriorRays[i]))}
    
###################################
# Simplify Weight vectors to Test #
###################################

allWeightsCell = {}
for i in range(len(vertexEqs)):
    allWeightsCell[i] = allWeightsCellMxl[i].values() + allWeightsCellFacets[i].values() + allWeightsCellRays[i].values()

# We compute primitive vectors with non-positive coefficients equivalent to each one of the sample vectors above, by taking a primitive vector. This is implemented in the function "makePrimitive"

allWeightsCellSimplified = {}
for i in range(len(vertexEqs)):
    allWeightsCellSimplified[i] = []
    for k in range(len(allWeightsCell[i])):
    	print k
    	allWeightsCellSimplified[i].append(makePrimitive(allWeightsCell[i][k]))

# [len(x) for x in allWeightsCellSimplified.values()]
# [27, 27, 27, 29, 16]

##############################################################
# Maximizing monomials for each vertex and each Sample Point #
##############################################################

# We take each Sample point for each vertex and compute the leading terms in x,y with respect to those weights:


# We load the polynomial of expected leading terms  for the cell of interest:

PolyCell =load("expectedLTPolysPerCells.sobj")[0]
 	 
allLTCell={}

for i in range(len(vertexEqs)):
    allLTCell[i]={x: LTFromWeights(PolyCell, allWeightsCellSimplified[i][x], RX) for x in range(len(allWeightsCellSimplified[i]))}




# Expectation: no cancellations occur (this should be double checked for non-maximal cells)
allLTCellMonomials={}
for i in range(len(vertexEqs)):
    print i
    allLTCellMonomials[i]={}
    for x in range(len(allWeightsCellSimplified[i])):
    	print x
        allLTCellMonomials[i][x]  = ProjectMonomials(LTFromWeights(RX(PolyCell), allWeightsCellSimplified[i][x], RX), Rxy, RX)


allLTCell[0]
{0: b5^8*b4^8*b34^2*b2^2*x - b5^8*b4^8*b34^2*b2^2*y + 2*b5^7*b4^6*b34^2*x*y - b5^7*b4^6*b34^2*y^2,
 1: 2*b5^6*b4^2*b2^2*x^2*y - 3*b5^6*b4^2*b2^2*x*y^2 + b5^6*b4^2*b2^2*y^3 + 4*b5^5*x^2*y^2 - 4*b5^5*x*y^3 + b5^5*y^4,
 2: b5^8*b4^8*b34^2*b2^2*x - b5^8*b4^8*b34^2*b2^2*y + 2*b5^7*b4^6*b34^2*x*y - b5^7*b4^6*b34^2*y^2,
 3: 2*b5^6*b4^2*b2^2*x^2*y - 3*b5^6*b4^2*b2^2*x*y^2 + b5^6*b4^2*b2^2*y^3 + 4*b5^5*x^2*y^2 - 4*b5^5*x*y^3 + b5^5*y^4,
 4: b5^8*b4^8*b34^2*b2^2*x - b5^8*b4^8*b34^2*b2^2*y + 2*b5^7*b4^6*b34^2*x*y - b5^7*b4^6*b34^2*y^2,
 5: 2*b5^6*b4^2*b2^2*x^2*y - 3*b5^6*b4^2*b2^2*x*y^2 + b5^6*b4^2*b2^2*y^3 + 4*b5^5*x^2*y^2 - 4*b5^5*x*y^3 + b5^5*y^4,
 6: b5^8*b4^8*b34^2*b2^2*x - b5^8*b4^8*b34^2*b2^2*y + 2*b5^7*b4^6*b34^2*x*y - b5^7*b4^6*b34^2*y^2,
 7: 2*b5^6*b4^2*b2^2*x^2*y - 3*b5^6*b4^2*b2^2*x*y^2 + b5^6*b4^2*b2^2*y^3 + 4*b5^5*x^2*y^2 - 4*b5^5*x*y^3 + b5^5*y^4,
 8: b5^8*b4^8*b34^2*b2^2*x - b5^8*b4^8*b34^2*b2^2*y + 2*b5^7*b4^6*b34^2*x*y - b5^7*b4^6*b34^2*y^2,
 9: 2*b5^6*b4^2*b2^2*x^2*y - 3*b5^6*b4^2*b2^2*x*y^2 + b5^6*b4^2*b2^2*y^3 + 4*b5^5*x^2*y^2 - 4*b5^5*x*y^3 + b5^5*y^4,
 10: 2*b5^6*b4^2*b2^2*x^2*y - 3*b5^6*b4^2*b2^2*x*y^2 + b5^6*b4^2*b2^2*y^3 + 4*b5^5*x^2*y^2 - 4*b5^5*x*y^3 + b5^5*y^4,
 11: 2*b5^6*b4^2*b2^2*x^2*y - 3*b5^6*b4^2*b2^2*x*y^2 + b5^6*b4^2*b2^2*y^3 + 4*b5^5*x^2*y^2 - 4*b5^5*x*y^3 + b5^5*y^4,
 12: b5^8*b4^8*b34^2*b2^2*x - b5^8*b4^8*b34^2*b2^2*y + 2*b5^7*b4^6*b34^2*x*y - b5^7*b4^6*b34^2*y^2,
 13: b5^8*b4^8*b34^2*b2^2*x - b5^8*b4^8*b34^2*b2^2*y + 2*b5^7*b4^6*b34^2*x*y - b5^7*b4^6*b34^2*y^2,
 14: 2*b5^6*b4^2*b2^2*x^2*y - 3*b5^6*b4^2*b2^2*x*y^2 + b5^6*b4^2*b2^2*y^3 + 4*b5^5*x^2*y^2 - 4*b5^5*x*y^3 + b5^5*y^4,
 15: b5^8*b4^8*b34^2*b2^2*x - b5^8*b4^8*b34^2*b2^2*y + 2*b5^7*b4^6*b34^2*x*y - b5^7*b4^6*b34^2*y^2,
 16: b5^8*b4^8*b34^2*b2^2*x - b5^8*b4^8*b34^2*b2^2*y + 2*b5^7*b4^6*b34^2*x*y - b5^7*b4^6*b34^2*y^2,
 17: b5^8*b4^8*b34^2*b2^2*x - b5^8*b4^8*b34^2*b2^2*y + 2*b5^7*b4^6*b34^2*x*y - b5^7*b4^6*b34^2*y^2,
 18: b5^8*b4^8*b34^2*b2^2*x - b5^8*b4^8*b34^2*b2^2*y + 2*b5^7*b4^6*b34^2*x*y - b5^7*b4^6*b34^2*y^2,
 19: 2*b5^6*b4^2*b2^2*x^2*y - 3*b5^6*b4^2*b2^2*x*y^2 + b5^6*b4^2*b2^2*y^3 + 4*b5^5*x^2*y^2 - 4*b5^5*x*y^3 + b5^5*y^4,
 20: 2*b5^6*b4^2*b2^2*x^2*y - 3*b5^6*b4^2*b2^2*x*y^2 + b5^6*b4^2*b2^2*y^3 + 4*b5^5*x^2*y^2 - 4*b5^5*x*y^3 + b5^5*y^4,
 21: 2*b5^6*b4^2*b2^2*x^2*y - 3*b5^6*b4^2*b2^2*x*y^2 + b5^6*b4^2*b2^2*y^3 + 4*b5^5*x^2*y^2 - 4*b5^5*x*y^3 + b5^5*y^4,
 22: b5^8*b4^8*b34^2*b2^2*x - b5^8*b4^8*b34^2*b2^2*y + 2*b5^7*b4^6*b34^2*x*y - b5^7*b4^6*b34^2*y^2,
 23: 2*b5^6*b4^2*b2^2*x^2*y - 3*b5^6*b4^2*b2^2*x*y^2 + b5^6*b4^2*b2^2*y^3 + 4*b5^5*x^2*y^2 - 4*b5^5*x*y^3 + b5^5*y^4,
 24: b5^8*b4^8*b34^2*b2^2*x - b5^8*b4^8*b34^2*b2^2*y + 2*b5^7*b4^6*b34^2*x*y - b5^7*b4^6*b34^2*y^2 + 2*b5^6*b4^2*b2^2*x^2*y - 3*b5^6*b4^2*b2^2*x*y^2 + b5^6*b4^2*b2^2*y^3 + 4*b5^5*x^2*y^2 - 4*b5^5*x*y^3 + b5^5*y^4,
 25: b5^8*b4^8*b34^2*b2^2*x - b5^8*b4^8*b34^2*b2^2*y + 2*b5^7*b4^6*b34^2*x*y - b5^7*b4^6*b34^2*y^2,
 26: b5^8*b4^8*b34^2*b2^2*x - b5^8*b4^8*b34^2*b2^2*y + 2*b5^7*b4^6*b34^2*x*y - b5^7*b4^6*b34^2*y^2}


allLTCellMonomials
{0: {0: x*y + y^2 + x + y,
  1: x^2*y^2 + x*y^3 + y^4 + x^2*y + x*y^2 + y^3,
  2: x*y + y^2 + x + y,
  3: x^2*y^2 + x*y^3 + y^4 + x^2*y + x*y^2 + y^3,
  4: x*y + y^2 + x + y,
  5: x^2*y^2 + x*y^3 + y^4 + x^2*y + x*y^2 + y^3,
  6: x*y + y^2 + x + y,
  7: x^2*y^2 + x*y^3 + y^4 + x^2*y + x*y^2 + y^3,
  8: x*y + y^2 + x + y,
  9: x^2*y^2 + x*y^3 + y^4 + x^2*y + x*y^2 + y^3,
  10: x^2*y^2 + x*y^3 + y^4 + x^2*y + x*y^2 + y^3,
  11: x^2*y^2 + x*y^3 + y^4 + x^2*y + x*y^2 + y^3,
  12: x*y + y^2 + x + y,
  13: x*y + y^2 + x + y,
  14: x^2*y^2 + x*y^3 + y^4 + x^2*y + x*y^2 + y^3,
  15: x*y + y^2 + x + y,
  16: x*y + y^2 + x + y,
  17: x*y + y^2 + x + y,
  18: x*y + y^2 + x + y,
  19: x^2*y^2 + x*y^3 + y^4 + x^2*y + x*y^2 + y^3,
  20: x^2*y^2 + x*y^3 + y^4 + x^2*y + x*y^2 + y^3,
  21: x^2*y^2 + x*y^3 + y^4 + x^2*y + x*y^2 + y^3,
  22: x*y + y^2 + x + y,
  23: x^2*y^2 + x*y^3 + y^4 + x^2*y + x*y^2 + y^3,
  24: x^2*y^2 + x*y^3 + y^4 + x^2*y + x*y^2 + y^3 + x*y + y^2 + x + y,
  25: x*y + y^2 + x + y,
  26: x*y + y^2 + x + y},
 1: {0: x^2*y^2 + x*y^3 + y^4,
  1: x^2*y^2 + x*y^3 + y^4,
  2: x^2*y^2 + x*y^3 + y^4,
  3: x^2*y^2 + x*y^3 + y^4,
  4: x^2*y^2 + x*y^3 + y^4,
  5: x^2*y^2 + x*y^3 + y^4,
  6: x^2*y^2 + x*y^3 + y^4,
  7: x^2*y^2 + x*y^3 + y^4,
  8: x^2*y^2 + x*y^3 + y^4,
  9: x^2*y^2 + x*y^3 + y^4,
  10: x^2*y^2 + x*y^3 + y^4,
  11: x^2*y^2 + x*y^3 + y^4,
  12: x^2*y^2 + x*y^3 + y^4,
  13: x^2*y^2 + x*y^3 + y^4,
  14: x^2*y^2 + x*y^3 + y^4,
  15: x^2*y^2 + x*y^3 + y^4,
  16: x^2*y^2 + x*y^3 + y^4,
  17: x^2*y^2 + x*y^3 + y^4,
  18: x^2*y^2 + x*y^3 + y^4,
  19: x^2*y^2 + x*y^3 + y^4,
  20: x^2*y^2 + x*y^3 + y^4,
  21: x^2*y^2 + x*y^3 + y^4,
  22: x^2*y^2 + x*y^3 + y^4,
  23: x^2*y^2 + x*y^3 + y^4,
  24: x^2*y^2 + x*y^3 + y^4,
  25: x^2*y^2 + x*y^3 + y^4,
  26: x^2*y^2 + x*y^3 + y^4},
 2: {0: x^2*y^2 + x*y^3 + y^4,
  1: x^2*y^2 + x*y^3 + y^4,
  2: x^2*y^2 + x*y^3 + y^4,
  3: x^2*y^2 + x*y^3 + y^4,
  4: x^2*y^2 + x*y^3 + y^4,
  5: x^2*y^2 + x*y^3 + y^4,
  6: x^2*y^2 + x*y^3 + y^4,
  7: x^2*y^2 + x*y^3 + y^4,
  8: x^2*y^2 + x*y^3 + y^4,
  9: x^2*y^2 + x*y^3 + y^4,
  10: x^2*y^2 + x*y^3 + y^4,
  11: x^2*y^2 + x*y^3 + y^4,
  12: x^2*y^2 + x*y^3 + y^4,
  13: x^2*y^2 + x*y^3 + y^4,
  14: x^2*y^2 + x*y^3 + y^4,
  15: x^2*y^2 + x*y^3 + y^4,
  16: x^2*y^2 + x*y^3 + y^4,
  17: x^2*y^2 + x*y^3 + y^4,
  18: x^2*y^2 + x*y^3 + y^4,
  19: x^2*y^2 + x*y^3 + y^4,
  20: x^2*y^2 + x*y^3 + y^4,
  21: x^2*y^2 + x*y^3 + y^4,
  22: x^2*y^2 + x*y^3 + y^4,
  23: x^2*y^2 + x*y^3 + y^4,
  24: x^2*y^2 + x*y^3 + y^4,
  25: x^2*y^2 + x*y^3 + y^4,
  26: x^2*y^2 + x*y^3 + y^4},
 3: {0: y^4 + y^3,
  1: y^4 + y^3,
  2: x^3*y + x^3,
  3: x^3*y + x^3,
  4: x*y + x,
  5: x^3*y + x^3,
  6: x^2*y^2 + x^2*y,
  7: x^2*y^2 + x^2*y,
  8: y^4 + y^3,
  9: x^3*y + x^2*y^2 + x^3 + x^2*y,
  10: x^2*y^2 + x^2*y,
  11: x*y + x,
  12: x*y + x,
  13: x^2*y^2 + x^2*y,
  14: x^2*y^2 + x*y^3 + y^4 + x^2*y + x*y^2 + y^3,
  15: x^3*y + x^3,
  16: x^2*y^2 + x*y^3 + y^4 + x^2*y + x*y^2 + y^3,
  17: x^3*y + x^2*y^2 + x^3 + x^2*y,
  18: x*y + x,
  19: x^3*y + x^3,
  20: x^2*y^2 + x*y^3 + y^4 + x^2*y + x*y^2 + y^3,
  21: x^3*y + x^2*y^2 + x^3 + x^2*y + x*y + x,
  22: x*y + x,
  23: x^2*y^2 + x^2*y + x*y + x,
  24: x*y + x,
  25: x^3*y + x^3 + x*y + x,
  26: x*y + x,
  27: x^4 + x^3*y + x^2*y^2 + x^3 + x^2*y,
  28: x*y + y^2 + x + y},
 4: {0: x^3*y + x^2*y^2,
  1: x^3*y + x^2*y^2,
  2: x^3*y + x^2*y^2,
  3: x^3*y + x^2*y^2,
  4: x^3*y + x^2*y^2,
  5: x^3*y + x^2*y^2,
  6: x^3*y + x^2*y^2,
  7: x^3*y + x^2*y^2,
  8: x^3*y + x^2*y^2,
  9: x^3*y + x^2*y^2,
  10: x^3*y + x^2*y^2,
  11: x^3*y + x^2*y^2,
  12: x^3*y + x^2*y^2,
  13: x^3*y + x^2*y^2,
  14: x^3*y + x^2*y^2,
  15: x^4 + x^3*y + x^2*y^2 + x^3 + x^2*y + x^2 + x*y + x}}
