###################################################
# Computations for Bad Primes for Igusa functions #
###################################################

# We check what happens to the Igusa invariants under an extension of the 3-adic valuation. This is the only case that needs to be analyzed since by our computations on "Qrefinementwithx34Noa4.sage", the leading terms of A, B and C, assuming trivial valuation on Q is:


# we load the polynomials and the ring:

load("Qrefinementwithx34Noa4.sage")


############################
# Type (I): Dumbbell Graph #
############################

weightsAs = [36,25,20,16,9,1]


LTA = LTFromWeights(A,weightsAs, S)
# # LTA
# # 6*a6^2*a5^2*a4^2
LTB = LTFromWeights(B,weightsAs, S)
# # LTB
# # 4*a6^4*a5^4*a4^2*a3^2
LTC = LTFromWeights(C,weightsAs, S)
# # LTC
# # 8*a6^6*a5^6*a4^4*a3^2

LTQ3 = LTFromWeights(Q3,weightsAs, S)
# LTQ3
# 8*a6^6*a5^6*a4^3*a3^3

LTQ4 = LTFromWeights(Q4,weightsAs, S)
# LTQ4
# -8*a6^6*a5^6*a4^4*a3^2


###########################################
# Bad primes computations A, B, C, Q3, Q4 #
###########################################

load("Qrefinementwithx34Noa4.sage")

# We need only check the primes dividing the coefficients of the leading terms:

BadPrimesA = computeBadPrimesOdd(S,LTA)

BadPrimesB = computeBadPrimesOdd(S,LTB)

BadPrimesC = computeBadPrimesOdd(S,LTC)

BadPrimesQ3 = computeBadPrimesOdd(S,LTQ3)

BadPrimesQ4 = computeBadPrimesOdd(S,LTQ4)

# Our findings give a list of badPrimes for all the polynomials (the prime 2 is discarded)
# print BadPrimesA
# [3]
# print BadPrimesB
# []
# print BadPrimesC
# []
# print BadPrimesQ3
# []
# print BadPrimesQ4
# []


#####################
# Computation for A #
#####################

# Since 3 is a bad prime for the presumed leading term of A, we must do a refined calculation:

(polynomialsAByCoefficients, LeadingTermsAByCoefficients, ExpLeadingTermAByCoefficients,CoefficientsABadPrimes,ExtraValuationToAddA,newValuationA,newValuationA,MaxTermsA) = trueValuationsPerPrimeAndWeightVector(S, A,weightsAs, BadPrimesA)

# We record the outputs:

# polynomialsAByCoefficients
# {4: -a6^2*a5^2*a4*a3 - a6^2*a5*a4^2*a3 - a6*a5^2*a4^2*a3 - a6^2*a5*a4*a3^2 - a6*a5^2*a4*a3^2 - a6*a5*a4^2*a3^2 - a6^2*a5^2*a4*a2 - a6^2*a5*a4^2*a2 - a6*a5^2*a4^2*a2 - a6^2*a5^2*a3*a2 - a6^2*a4^2*a3*a2 - a5^2*a4^2*a3*a2 - a6^2*a5*a3^2*a2 - a6*a5^2*a3^2*a2 - a6^2*a4*a3^2*a2 - a5^2*a4*a3^2*a2 - a6*a4^2*a3^2*a2 - a5*a4^2*a3^2*a2 - a6^2*a5*a4*a2^2 - a6*a5^2*a4*a2^2 - a6*a5*a4^2*a2^2 - a6^2*a5*a3*a2^2 - a6*a5^2*a3*a2^2 - a6^2*a4*a3*a2^2 - a5^2*a4*a3*a2^2 - a6*a4^2*a3*a2^2 - a5*a4^2*a3*a2^2 - a6*a5*a3^2*a2^2 - a6*a4*a3^2*a2^2 - a5*a4*a3^2*a2^2 - a6^2*a5^2*a4*a1 - a6^2*a5*a4^2*a1 - a6*a5^2*a4^2*a1 - a6^2*a5^2*a3*a1 - a6^2*a4^2*a3*a1 - a5^2*a4^2*a3*a1 - a6^2*a5*a3^2*a1 - a6*a5^2*a3^2*a1 - a6^2*a4*a3^2*a1 - a5^2*a4*a3^2*a1 - a6*a4^2*a3^2*a1 - a5*a4^2*a3^2*a1 - a6^2*a5^2*a2*a1 - a6^2*a4^2*a2*a1 - a5^2*a4^2*a2*a1 - a6^2*a3^2*a2*a1 - a5^2*a3^2*a2*a1 - a4^2*a3^2*a2*a1 - a6^2*a5*a2^2*a1 - a6*a5^2*a2^2*a1 - a6^2*a4*a2^2*a1 - a5^2*a4*a2^2*a1 - a6*a4^2*a2^2*a1 - a5*a4^2*a2^2*a1 - a6^2*a3*a2^2*a1 - a5^2*a3*a2^2*a1 - a4^2*a3*a2^2*a1 - a6*a3^2*a2^2*a1 - a5*a3^2*a2^2*a1 - a4*a3^2*a2^2*a1 - a6^2*a5*a4*a1^2 - a6*a5^2*a4*a1^2 - a6*a5*a4^2*a1^2 - a6^2*a5*a3*a1^2 - a6*a5^2*a3*a1^2 - a6^2*a4*a3*a1^2 - a5^2*a4*a3*a1^2 - a6*a4^2*a3*a1^2 - a5*a4^2*a3*a1^2 - a6*a5*a3^2*a1^2 - a6*a4*a3^2*a1^2 - a5*a4*a3^2*a1^2 - a6^2*a5*a2*a1^2 - a6*a5^2*a2*a1^2 - a6^2*a4*a2*a1^2 - a5^2*a4*a2*a1^2 - a6*a4^2*a2*a1^2 - a5*a4^2*a2*a1^2 - a6^2*a3*a2*a1^2 - a5^2*a3*a2*a1^2 - a4^2*a3*a2*a1^2 - a6*a3^2*a2*a1^2 - a5*a3^2*a2*a1^2 - a4*a3^2*a2*a1^2 - a6*a5*a2^2*a1^2 - a6*a4*a2^2*a1^2 - a5*a4*a2^2*a1^2 - a6*a3*a2^2*a1^2 - a5*a3*a2^2*a1^2 - a4*a3*a2^2*a1^2,
#  6: a6^2*a5^2*a4^2 + a6^2*a5^2*a3^2 + a6^2*a4^2*a3^2 + a5^2*a4^2*a3^2 + a6^2*a5^2*a2^2 + a6^2*a4^2*a2^2 + a5^2*a4^2*a2^2 + a6^2*a3^2*a2^2 + a5^2*a3^2*a2^2 + a4^2*a3^2*a2^2 + a6^2*a5^2*a1^2 + a6^2*a4^2*a1^2 + a5^2*a4^2*a1^2 + a6^2*a3^2*a1^2 + a5^2*a3^2*a1^2 + a4^2*a3^2*a1^2 + a6^2*a2^2*a1^2 + a5^2*a2^2*a1^2 + a4^2*a2^2*a1^2 + a3^2*a2^2*a1^2,
#  12: a6^2*a5*a4*a3*a2 + a6*a5^2*a4*a3*a2 + a6*a5*a4^2*a3*a2 + a6*a5*a4*a3^2*a2 + a6*a5*a4*a3*a2^2 + a6^2*a5*a4*a3*a1 + a6*a5^2*a4*a3*a1 + a6*a5*a4^2*a3*a1 + a6*a5*a4*a3^2*a1 + a6^2*a5*a4*a2*a1 + a6*a5^2*a4*a2*a1 + a6*a5*a4^2*a2*a1 + a6^2*a5*a3*a2*a1 + a6*a5^2*a3*a2*a1 + a6^2*a4*a3*a2*a1 + a5^2*a4*a3*a2*a1 + a6*a4^2*a3*a2*a1 + a5*a4^2*a3*a2*a1 + a6*a5*a3^2*a2*a1 + a6*a4*a3^2*a2*a1 + a5*a4*a3^2*a2*a1 + a6*a5*a4*a2^2*a1 + a6*a5*a3*a2^2*a1 + a6*a4*a3*a2^2*a1 + a5*a4*a3*a2^2*a1 + a6*a5*a4*a3*a1^2 + a6*a5*a4*a2*a1^2 + a6*a5*a3*a2*a1^2 + a6*a4*a3*a2*a1^2 + a5*a4*a3*a2*a1^2,
#  120: -a6*a5*a4*a3*a2*a1}

# LeadingTermsAByCoefficients
# {4: -a6^2*a5^2*a4*a3,
#  6: a6^2*a5^2*a4^2,
#  12: a6^2*a5*a4*a3*a2,
#  120: -a6*a5*a4*a3*a2*a1}

# ExpLeadingTermAByCoefficients
# {4: (2, 2, 1, 1, 0, 0),
#  6: (2, 2, 2, 0, 0, 0),
#  12: (2, 1, 1, 1, 1, 0),
#  120: (1, 1, 1, 1, 1, 1)}

# CoefficientsABadPrimes
# {4: [], 6: [3], 12: [3], 120: [3, 5]}

# ExtraValuationToAddA
# {4: [0], 6: [-1], 12: [-1], 120: [-1, -1]}

# MaxTermsA
# {3: [(6, -1, a6^2*a5^2*a4^2)]}

# We compare the weights of the leading terms of each piece with respect to the negative 3-adic valuation (Recall our choice of weights is weightsAs = [36, 25, 20, 16, 9, 1])

# Coeff4 = 2*w6 +2*w5+ w4 + w3
# Coeff6 = -1 + 2*w6 + 2*w5 + 2*w4
# Coeff12 = -1 + 2*w6 + w5 + w4+ w3 + w2
# Coeff120 = -1 + w6 + w5 + w4 + w3 + w2 + w1

# The winners are Coeff4 and Coeff6, so the computation boils down to comparing w3 and w4 - 1. There are three cases to analyze:

########################
# Case 1 : w4 - 1 > w3 #
########################

# newLTA = 6*LeadingTermsAByCoefficients[6]
# newLTA
# 6*a6^2*a5^2*a4^2
# newLTA *LTB /LTC
# 3

# We can cancel the leading terms and the calculations from the characteristic 0 case apply.

########################
# Case 2 : w4 - 1 < w3 #
########################

# newLTA = 4*LeadingTermsAByCoefficients[4]
# newLTA
# -4*a6^2*a5^2*a4*a3
# newLTA*LTB
# -16*a6^6*a5^6*a4^3*a3^3
# LTC
# 8*a6^6*a5^6*a4^4*a3^2
# newLTA*LTB/LTC
# (-16*a3)/(8*a4)
# newLTA*LTB-3*LTC
# -24*a6^6*a5^6*a4^4*a3^2 - 16*a6^6*a5^6*a4^3*a3^3
# newLTA*LTB-4*LTC
# -32*a6^6*a5^6*a4^4*a3^2 - 16*a6^6*a5^6*a4^3*a3^3
# In both cases, the leading terms are -16*a6^6*a5^6*a4^3*a3^3 and their weight is 6*(w6+w5) + 3*(w4+w3)



########################
# Case 3 : w4 - 1 = w3 #
########################


# We must change the weight:
weightsAs = [36, 25, 20, 19, 9, 1]

(polynomialsAByCoefficients, LeadingTermsAByCoefficients, ExpLeadingTermAByCoefficients,CoefficientsABadPrimes,ExtraValuationToAddA,newValuationA,newValuationA,MaxTermsA) = trueValuationsPerPrimeAndWeightVector(S, A,weightsAs, BadPrimesA)

# LeadingTermsAByCoefficients
# {4: -a6^2*a5^2*a4*a3,
#  6: a6^2*a5^2*a4^2,
#  12: a6^2*a5*a4*a3*a2,
#  120: -a6*a5*a4*a3*a2*a1}

# MaxTermsA
# {3: [(4, 0, -a6^2*a5^2*a4*a3), (6, -1, a6^2*a5^2*a4^2)]}

# newLTA = 4*LeadingTermsAByCoefficients[4] + 6*LeadingTermsAByCoefficients[6]
# newLTA
# 6*a6^2*a5^2*a4^2 - 4*a6^2*a5^2*a4*a3
# factor(newLTA)
# (-2) * (-3*a4 + 2*a3) * a4 * a5^2 * a6^2

# # The valuation is the expected one iff no cancellation occurs!

# newLTA*LTB
# 24*a6^6*a5^6*a4^4*a3^2 - 16*a6^6*a5^6*a4^3*a3^3
# newLTA*LTB-3*LTC
# -16*a6^6*a5^6*a4^3*a3^3
# In this case,  no cancellation occurs. We can proceed with Q3 as in the characteristic 0 case.
# newLTA*LTB-4*LTC
# -8*a6^6*a5^6*a4^4*a3^2 - 16*a6^6*a5^6*a4^3*a3^3
# factor(newLTA*LTB-4*LTC)
# factor(newLTA*LTB-4*LTC)
# (-8) * (a4 + 2*a3) * a3^2 * a4^3 * a5^6 * a6^6
# In this case, since w4 = w3+1, then val(a4+2*a3)  = -w4, so no cancellation occures. We can proceed with Q4 as in the characteristic 0 case.

# The only issue that remains is when val(-3*a4 + 2*a3) > -w3 = 1 - w4





####################
# Type (II): Theta #
####################

weightsAsT = [36,25,10,16,9,1]

# LTAT = LTFromWeights(AT,weightsAsT, S)
# # LTAT
# # 8*a6^2*a5^2*a3^2
# LTBT = LTFromWeights(BT,weightsAsT, S)
# # LTBT
# # 4*a6^4*a5^4*a3^4
# LTCT = LTFromWeights(CT,weightsAsT, S)
# # LTCT
# # 8*a6^6*a5^6*a3^6


# LTQ4T = LTFromWeights(QT4,weightsAsT, S)
# LTQ4T
# -8*a6^6*a5^6*a4^4*a3^2

# There is no characteristic issue in this case.