##############################################
# Computing initial forms of A4, A6, and A12 #
##############################################

# We use the computation of the Groebner fans and the subdivisions on each cell of M_2^trop done on the files:
# "GrobnerConeComputationsAchar3.sage"
# to compute the possible initial forms of each polynomial in the decomposition of A done in "Qrefinementwithx34Noa4BadPrimes.sage"
# Recall that the Theta cone presented no characteristic issues, so it was not considered for our computations.

# The precise genericity conditions are established by checking their residue classes of these initial forms with respect to the section  w |--> 3^{w} to the valuation on K, and certifying they do not vanish. In our case, this is achieved by dividing by 3 and replacing each branch point by their initial form.


# The polynomials A4, A6 and A12 induce no subdivision, and the polynomial A120 is a monomial. The sample points are computed in "allConesGenus2.sage"

load("macroslocalJInvariantComputationsAndPrimesWithBadReduction.sage")


# The polynomials are encoded in the following file, which we load.

load("Qrefinementwithx34Noa4BadPrimes.sage")

A4 = polynomialsAByCoefficients[4]
A6 = polynomialsAByCoefficients[6]
A12 = polynomialsAByCoefficients[12]
A120 = polynomialsAByCoefficients[120]

# The ring S contains the variables a6 through a1.

# We create the fraction field of the ambient polynomial rings
K = FractionField(S); 

# We try to factor over F_3[a6,a5,a4,a3,a2,a1]

k = GF(3);
k.<a6, a5, a4, a3, a2,a1> = PolynomialRing(k)


# The sample points for no subdivisions are obtained by loading the following file

load("allConesGenus2.sage")



#################
# Polynomial A4 #
#################

##############################################
# Computation of leading terms for each cone #
##############################################

#################
# Dumbbell Cone #
#################

leadA4Dumbbell = computeLTSample(pointDumbbell,S,A4)
# print factor(leadA4Dumbbell)
# (-1) * a3 * a4 * a5^2 * a6^2

#####################
# Figure Eight Cone #
#####################

leadA4FigEight = computeLTSample(pointFigEight,S,A4)
# print factor(leadA4FigEight)
# (-1) * a3 * a4 * a5^2 * a6^2

###############
# TypeIV Cone #
###############

leadA4TypeIV = computeLTSample(pointTypeIV,S,A4)
# print factor(leadA4TypeIV)
# (-1) * a3 * a4 * a5 * (a5 + a4) * a6^2

##############
# TypeV Cone #
##############

leadA4TypeV = computeLTSample(pointTypeV,S,A4)
# print factor(leadA4TypeV)
# (-1) * (a3 + a2) * a4 * a5 * (a5 + a4) * a6^2

###############
# TypeVI Cone #
###############

leadA4TypeVI = computeLTSample(pointTypeVI,S,A4)
# print factor(leadA4TypeVI)
# (-1) * a3 * a4 * a5 * (a5 + a4 + a3) * a6^2

################
# TypeVII Cone #
################

leadA4TypeVII = computeLTSample(pointTypeVII,S,A4)
# print factor(leadA4TypeVII)
# (-1) * a6^2 * (a5^2*a4*a3 + a5*a4^2*a3 + a5*a4*a3^2 + a5^2*a4*a2 + a5*a4^2*a2 + a5^2*a3*a2 + a4^2*a3*a2 + a5*a3^2*a2 + a4*a3^2*a2 + a5*a4*a2^2 + a5*a3*a2^2 + a4*a3*a2^2)

######################
# CONCLUSION  for A4 #
######################

# We verify that A6 has the same leading term for Dumbbell and Figure Eight cones
# leadA4Dumbbell == leadA4FigEight
# True
# factor(leadA4FigEight)
# (-1) * a3 * a4 * a5^2 * a6^2
# factor(leadA4TypeIV)
# (-1) * a3 * a4 * a5 * (a5 + a4) * a6^2
# factor(leadA4TypeV)
# (-1) * (a3 + a2) * a4 * a5 * (a5 + a4) * a6^2
# factor(leadA4TypeVI)
# (-1) * a3 * a4 * a5 * (a5 + a4 + a3) * a6^2
# factor(leadA4TypeVII)
# (-1) * a6^2 * (a5^2*a4*a3 + a5*a4^2*a3 + a5*a4*a3^2 + a5^2*a4*a2 + a5*a4^2*a2 + a5^2*a3*a2 + a4^2*a3*a2 + a5*a3^2*a2 + a4*a3^2*a2 + a5*a4*a2^2 + a5*a3*a2^2 + a4*a3*a2^2)




################################################################################



#################
# Polynomial A6 #
#################

##############################################
# Computation of leading terms for each cone #
##############################################


#################
# Dumbbell Cone #
#################

leadA6Dumbbell = computeLTSample(pointDumbbell,S,A6)
# print leadA6Dumbbell
# a6^2*a5^2*a4^2

#####################
# Figure Eight Cone #
#####################

leadA6FigEight = computeLTSample(pointFigEight,S,A6)
# print factor(leadA6FigEight)
# a5^2 * a6^2 * (a4^2 + a3^2)

###############
# TypeIV Cone #
###############

leadA6TypeIV = computeLTSample(pointTypeIV,S,A6)
# print factor(leadA6TypeIV)
# a4^2 * a5^2 * a6^2

##############
# TypeV Cone #
##############

leadA6TypeV = computeLTSample(pointTypeV,S,A6)
# print factor(leadA6TypeV)
# a4^2 * a5^2 * a6^2

###############
# TypeVI Cone #
###############

leadA6TypeVI = computeLTSample(pointTypeVI,S,A6)
# print factor(leadA6TypeVI)
# a6^2 * (a5^2*a4^2 + a5^2*a3^2 + a4^2*a3^2)


################
# TypeVII Cone #
################

leadA6TypeVII = computeLTSample(pointTypeVII,S,A6)
print factor(leadA6TypeVII)
# a6^2 * (a5^2*a4^2 + a5^2*a3^2 + a4^2*a3^2 + a5^2*a2^2 + a4^2*a2^2 + a3^2*a2^2)


######################
# CONCLUSION  for A6 #
######################
# We verify that A6 has the same leading term for Dumbbell, TypeIV and TypeV 
# leadA6Dumbbell == leadA6TypeIV
# True
# leadA6Dumbbell == leadA6TypeV
# True
# factor(leadA6Dumbbell)
# a4^2 * a5^2 * a6^2
# factor(leadA6FigEight)
# a5^2 * a6^2 * (a4^2 + a3^2)
# factor(leadA6TypeVI)
# a6^2 * (a5^2*a4^2 + a5^2*a3^2 + a4^2*a3^2)
# factor(leadA6TypeVII)
# a6^2 * (a5^2*a4^2 + a5^2*a3^2 + a4^2*a3^2 + a5^2*a2^2 + a4^2*a2^2 + a3^2*a2^2)


################################################################################



##################
# Polynomial A12 #
##################

##############################################
# Computation of leading terms for each cone #
##############################################

#################
# Dumbbell Cone #
#################

leadA12Dumbbell = computeLTSample(pointDumbbell,S,A12)
# print factor(leadA12Dumbbell)
# a6^2*a5*a4*a3*a2

#####################
# Figure Eight Cone #
#####################

leadA12FigEight = computeLTSample(pointFigEight,S,A12)
# print factor(leadA12FigEight)
# a2 * a3 * a4 * a5 * a6^2

###############
# TypeIV Cone #
###############

leadA12TypeIV = computeLTSample(pointTypeIV,S,A12)
# print factor(leadA12TypeIV)
# a2 * a3 * a4 * a5 * a6^2

##############
# TypeV Cone #
##############

leadA12TypeV = computeLTSample(pointTypeV,S,A12)
print factor(leadA12TypeV)
# a2 * a3 * a4 * a5 * a6^2

###############
# TypeVI Cone #
###############

leadA12TypeVI = computeLTSample(pointTypeVI,S,A12)
# print factor(leadA12TypeVI)
# a2 * a3 * a4 * a5 * a6^2

################
# TypeVII Cone #
################

leadA12TypeVII = computeLTSample(pointTypeVII,S,A12)
# print factor(leadA12TypeVII)
# a2 * a3 * a4 * a5 * a6^2

#######################
# CONCLUSION  for A12 #
#######################

# We verify that A12 has the same leading term for all cones except the Theta cone.
# leadA12Dumbbell == leadA12TypeVII
# True
# factor(leadA12TypeVII)
# a2 * a3 * a4 * a5 * a6^2



###################
# Polynomial A120 #
###################

# print A120
# -a6*a5*a4*a3*a2*a1



########################################################################
# We compute the sum of the terms divisible by 3 and the leading terms #
########################################################################

# To compute the leading term in A - 4*A4, we must take into account  the choice of section w |--> 3^{w} to the valuation. This forces us to consider Q = (A - 4*A4)/3.

Q = (6*A6 + 12*A12 + 120*A120)/3

# Since the summands of Q have disjoint supports, we know that the leading term of Q is constant on all cells of M_2^trop.

##############################################
# Computation of leading terms for each cone #
##############################################

#################
# Dumbbell Cone #
#################

leadQDumbbell = computeLTSample(pointDumbbell,S,Q)
# print factor(leadQDumbbell)
# (2) * a4^2 * a5^2 * a6^2

#####################
# Figure Eight Cone #
#####################

leadQFigEight = computeLTSample(pointFigEight,S,Q)
# print factor(leadQFigEight)
# (2) * a5^2 * a6^2 * (a4^2 + a3^2)

###############
# TypeIV Cone #
###############

leadQTypeIV = computeLTSample(pointTypeIV,S,Q)
# print factor(leadQTypeIV)
 #(2) * a4^2 * a5^2 * a6^2

##############
# TypeV Cone #
##############

leadQTypeV = computeLTSample(pointTypeV,S,Q)
# print factor(leadQTypeV)
# (2) * a4^2 * a5^2 * a6^2

###############
# TypeVI Cone #
###############

leadQTypeVI = computeLTSample(pointTypeVI,S,Q)
# print factor(leadQTypeVI)
# (2) * a6^2 * (a5^2*a4^2 + a5^2*a3^2 + a4^2*a3^2)

################
# TypeVII Cone #
################

leadQTypeVII = computeLTSample(pointTypeVII,S,Q)
# print factor(leadQTypeVII)
# (2) * a6^2 * (a5^2*a4^2 + a5^2*a3^2 + a4^2*a3^2 + 2*a5*a4*a3*a2 + a5^2*a2^2 + a4^2*a2^2 + a3^2*a2^2)

####################
# CONCLUSION FOR Q #
####################

# We verify that Q has the same leading term for Dumbbell, TypeIV and TypeV 
# leadQDumbbell == leadQTypeIV
# True
# leadQDumbbell == leadQTypeV
# True
# print factor(leadQDumbbell)
# (2) * a4^2 * a5^2 * a6^2
# print factor(leadQFigEight)
# (2) * a5^2 * a6^2 * (a4^2 + a3^2)
# print factor(leadQTypeV)
# (2) * a4^2 * a5^2 * a6^2
print factor(leadQTypeVI)
# (2) * a6^2 * (a5^2*a4^2 + a5^2*a3^2 + a4^2*a3^2)
# print factor(leadQTypeVII)
# (2) * a6^2 * (a5^2*a4^2 + a5^2*a3^2 + a4^2*a3^2 + 2*a5*a4*a3*a2 + a5^2*a2^2 + a4^2*a2^2 + a3^2*a2^2)


# We try to factor over k = F_3[a6,a5,a4,a3,a2,a1]

# print factor(k(leadQTypeVI))
# (-1) * a6^2 * (a5^2*a4^2 + a5^2*a3^2 + a4^2*a3^2)
# print factor(k(leadQTypeVII))
# (-1) * a6^2 * (a5^2*a4^2 + a5^2*a3^2 + a4^2*a3^2 - a5*a4*a3*a2 + a5^2*a2^2 + a4^2*a2^2 + a3^2*a2^2)


###############
# CONCLUSION: #
###############

# None of the monomials in the support of A4 and Q hace integer multiples of 3 as factors: the valuation of these coefficients is always zero.

# Dumbbell: both 4*A4 and 3*Q have monomials as their leading terms. In characteristic 3,  the valuations are:
# For 4*A4: w3 + w4 + 2*w5 + 2w6
# For 3*Q: -1 + 2*w4 +  2*w5 + 2w6
Thus, the true valuation will be obtained by comparing w3 to w4 - 1. 

# For the lower dimensional cells, assuming there is no cancellation among the leading terms of A4 and Q individually, the true valuation will be obtained by comparing the same 2 quantities. When w3 = w4-1, in addition to the genericity obtained from each individual leading form, we must ensure no cancellation occurs between these two leading forms.

# Notice that: the class of 4 agrees with the class of 1, so we don't need to work with 4*leadA4.



#################
# Dumbbell Cone #
#################

# factor(leadA4Dumbbell + leadQDumbbell)
# (-1) * (-2*a4 + a3) * a4 * a5^2 * a6^2

# factor(k(leadA4Dumbbell + leadQDumbbell))
# (-1) * a4 * (a4 + a3) * a5^2 * a6^2

#####################
# Figure Eight Cone #
#####################

# factor(leadA4FigEight + leadQFigEight)
# a5^2 * a6^2 * (2*a4^2 - a4*a3 + 2*a3^2)

# factor(k(leadA4FigEight + leadQFigEight))
# (-1) * (a4 - a3)^2 * a5^2 * a6^2

###############
# TypeIV Cone #
###############

# factor(leadA4TypeIV + leadQTypeIV)
# (-1) * a4 * a5 * a6^2 * (-2*a5*a4 + a5*a3 + a4*a3)

# factor(k(leadA4TypeIV + leadQTypeIV))
# (-1) * a4 * a5 * a6^2 * (a5*a4 + a5*a3 + a4*a3)

##############
# TypeV Cone #
##############

# factor(leadA4TypeV + leadQTypeV)
# (-1) * a4 * a5 * a6^2 * (-2*a5*a4 + a5*a3 + a4*a3 + a5*a2 + a4*a2)

# factor(k(leadA4TypeV + leadQTypeV))
# (-1) * a4 * a5 * a6^2 * (a5*a4 + a5*a3 + a4*a3 + a5*a2 + a4*a2)

###############
# TypeVI Cone #
###############

# factor(leadA4TypeVI + leadQTypeVI)
# a6^2 * (2*a5^2*a4^2 - a5^2*a4*a3 - a5*a4^2*a3 + 2*a5^2*a3^2 - a5*a4*a3^2 + 2*a4^2*a3^2)

# factor(k(leadA4TypeVI + leadQTypeVI))
# (-1) * a6^2 * (a5^2*a4^2 + a5^2*a4*a3 + a5*a4^2*a3 + a5^2*a3^2 + a5*a4*a3^2 + a4^2*a3^2)

################
# TypeVII Cone #
################

# factor(leadA4TypeVII + leadQTypeVII)
# a6^2 * (2*a5^2*a4^2 - a5^2*a4*a3 - a5*a4^2*a3 + 2*a5^2*a3^2 - a5*a4*a3^2 + 2*a4^2*a3^2 - a5^2*a4*a2 - a5*a4^2*a2 - a5^2*a3*a2 + 4*a5*a4*a3*a2 - a4^2*a3*a2 - a5*a3^2*a2 - a4*a3^2*a2 + 2*a5^2*a2^2 - a5*a4*a2^2 + 2*a4^2*a2^2 - a5*a3*a2^2 - a4*a3*a2^2 + 2*a3^2*a2^2)

# factor(k(leadA4TypeVII + leadQTypeVII))
# (-1) * a6^2 * (a5^2*a4^2 + a5^2*a4*a3 + a5*a4^2*a3 + a5^2*a3^2 + a5*a4*a3^2 + a4^2*a3^2 + a5^2*a4*a2 + a5*a4^2*a2 + a5^2*a3*a2 - a5*a4*a3*a2 + a4^2*a3*a2 + a5*a3^2*a2 + a4*a3^2*a2 + a5^2*a2^2 + a5*a4*a2^2 + a4^2*a2^2 + a5*a3*a2^2 + a4*a3*a2^2 + a3^2*a2^2)


#################################################
# CONCLUSIONS: 3 possible genericity conditions #
#################################################