#############################################
# Computing initial forms of A, B, C and Q4 #
#############################################

# We use the computation of the Groebner fans and the subdivisions on each cell of M_2^trop done on the files:
# "GrobnerConeComputationsA.sage"
# "GrobnerConeComputationsB.sage"
# "GrobnerConeComputationsC.sage"
# "GrobnerConeComputationsQ4.sage"
# to compute the possible initial forms of each polynomial. Assuming no cancellations of initial forms occur, we observe that the only polynomial with characteristic issues is A, and the relevant cones are the Dumbbell cone, and the TypeIV and TypeV cones, ie. those that are not obtained from a degeneration of the Theta cone.

# The polynomials A, B, and C induce no subdivision. The polynomial Q4 induces a subdivision of the Theta cone into 3 cells (and the 4 intersections). The sample points are computed in "allConesGenus2.sage" and "Qrefinementwithx34Noa4.sage"


load("macroslocalJInvariantComputationsAndPrimesWithBadReduction.sage")


# The polynomials and their versions adapted to the Theta Cone (by replacing a4 with x34 = x4-x3) are encoded in the following file, which we load.

load("Qrefinementwithx34Noa4.sage")

# The ring S contains the variables a6 through a1, and the ring SS contains the variables a6, a5, x34, a3, a2, a1.

# We create the fraction field of the ambient polynomial rings
K = FractionField(S); 
KK = FractionField(SS);


# The sample points for no subdivisions are obtained by loading the following file

load("allConesGenus2.sage")

################
# Polynomial A #
################

##############################################
# Computation of leading terms for each cone #
##############################################


#################
# Dumbbell Cone #
#################

leadADumbbell = computeLTSample(pointDumbbell,S,A)
# print leadADumbbell
# 6*a6^2*a5^2*a4^2

#####################
# Figure Eight Cone #
#####################

leadAFigEight = computeLTSample(pointFigEight,S,A)
# print factor(leadAFigEight)
# (2) * a5^2 * a6^2 * (3*a4^2 - 2*a4*a3 + 3*a3^2)



###############
# TypeIV Cone #
###############

leadATypeIV = computeLTSample(pointTypeIV,S,A)
# print factor(leadATypeIV)
# (6) * a4^2 * a5^2 * a6^2


##############
# TypeV Cone #
##############

leadATypeV = computeLTSample(pointTypeV,S,A)
# print factor(leadATypeV)
# (6) * a4^2 * a5^2 * a6^2


###############
# TypeVI Cone #
###############

leadATypeVI = computeLTSample(pointTypeVI,S,A)
# print factor(leadATypeVI)
# (2) * a6^2 * (3*a5^2*a4^2 - 2*a5^2*a4*a3 - 2*a5*a4^2*a3 + 3*a5^2*a3^2 - 2*a5*a4*a3^2 + 3*a4^2*a3^2)

################
# TypeVII Cone #
################

leadATypeVII = computeLTSample(pointTypeVII,S,A)
# print factor(leadATypeVII)
# (2) * a6^2 * (3*a5^2*a4^2 - 2*a5^2*a4*a3 - 2*a5*a4^2*a3 + 3*a5^2*a3^2 - 2*a5*a4*a3^2 + 3*a4^2*a3^2 - 2*a5^2*a4*a2 - 2*a5*a4^2*a2 - 2*a5^2*a3*a2 + 6*a5*a4*a3*a2 - 2*a4^2*a3*a2 - 2*a5*a3^2*a2 - 2*a4*a3^2*a2 + 3*a5^2*a2^2 - 2*a5*a4*a2^2 + 3*a4^2*a2^2 - 2*a5*a3*a2^2 - 2*a4*a3*a2^2 + 3*a3^2*a2^2)


##############
# Theta Cone #
##############

leadATTheta = computeLTSample(pointTheta,SS,AT)
# print factor(leadATTheta)
# (8) * a3^2 * a5^2 * a6^2

###########################################################################
# CONCLUSION: We have characteristic issues for char = 2 and 3, but only on Dumbbell, TypeIV and TypeV cones. We treat the char =3  case separately in "
###########################################################################



################################################################################


################
# Polynomial B #
################

##############################################
# Computation of leading terms for each cone #
##############################################


#################
# Dumbbell Cone #
#################

leadBDumbbell = computeLTSample(pointDumbbell,S,B)
# print leadBDumbbell
# 4*a6^4*a5^4*a4^2*a3^2



#####################
# Figure Eight Cone #
#####################

leadBFigEight = computeLTSample(pointFigEight,S,B)
# print factor(leadBFigEight)
# (4) * a3^2 * a4^2 * a5^4 * a6^4


###############
# TypeIV Cone #
###############

leadBTypeIV = computeLTSample(pointTypeIV,S,B)
# print factor(leadBTypeIV)
# (4) * a3^2 * a4^2 * a5^2 * a6^4 * (a5^2 - a5*a4 + a4^2)

##############
# TypeV Cone #
##############

leadBTypeV = computeLTSample(pointTypeV,S,B)
# print factor(leadBTypeV)
# (4) * a4^2 * a5^2 * a6^4 * (a3^2 - a3*a2 + a2^2) * (a5^2 - a5*a4 + a4^2)

###############
# TypeVI Cone #
###############

leadBTypeVI = computeLTSample(pointTypeVI,S,B)
print factor(leadBTypeVI)
# (4) * a3^2 * a4^2 * a5^2 * a6^4 * (a5^2 - a5*a4 + a4^2 - a5*a3 - a4*a3 + a3^2)

################
# TypeVII Cone #
################

leadBTypeVII = computeLTSample(pointTypeVII,S,B)
# print factor(leadBTypeVII)
# (4) * a6^4 * (a5^4*a4^2*a3^2 - a5^3*a4^3*a3^2 + a5^2*a4^4*a3^2 - a5^3*a4^2*a3^3 - a5^2*a4^3*a3^3 + a5^2*a4^2*a3^4 - a5^4*a4^2*a3*a2 + a5^3*a4^3*a3*a2 - a5^2*a4^4*a3*a2 - a5^4*a4*a3^2*a2 + a5^3*a4^2*a3^2*a2 + a5^2*a4^3*a3^2*a2 - a5*a4^4*a3^2*a2 + a5^3*a4*a3^3*a2 + a5^2*a4^2*a3^3*a2 + a5*a4^3*a3^3*a2 - a5^2*a4*a3^4*a2 - a5*a4^2*a3^4*a2 + a5^4*a4^2*a2^2 - a5^3*a4^3*a2^2 + a5^2*a4^4*a2^2 - a5^4*a4*a3*a2^2 + a5^3*a4^2*a3*a2^2 + a5^2*a4^3*a3*a2^2 - a5*a4^4*a3*a2^2 + a5^4*a3^2*a2^2 + a5^3*a4*a3^2*a2^2 - 6*a5^2*a4^2*a3^2*a2^2 + a5*a4^3*a3^2*a2^2 + a4^4*a3^2*a2^2 - a5^3*a3^3*a2^2 + a5^2*a4*a3^3*a2^2 + a5*a4^2*a3^3*a2^2 - a4^3*a3^3*a2^2 + a5^2*a3^4*a2^2 - a5*a4*a3^4*a2^2 + a4^2*a3^4*a2^2 - a5^3*a4^2*a2^3 - a5^2*a4^3*a2^3 + a5^3*a4*a3*a2^3 + a5^2*a4^2*a3*a2^3 + a5*a4^3*a3*a2^3 - a5^3*a3^2*a2^3 + a5^2*a4*a3^2*a2^3 + a5*a4^2*a3^2*a2^3 - a4^3*a3^2*a2^3 - a5^2*a3^3*a2^3 + a5*a4*a3^3*a2^3 - a4^2*a3^3*a2^3 + a5^2*a4^2*a2^4 - a5^2*a4*a3*a2^4 - a5*a4^2*a3*a2^4 + a5^2*a3^2*a2^4 - a5*a4*a3^2*a2^4 + a4^2*a3^2*a2^4)



##############
# Theta Cone #
##############

leadBTTheta = computeLTSample(pointTheta,SS,BT)
# print factor(leadBTTheta)
# (4) * a3^4 * a5^4 * a6^4


#############################################################
# CONCLUSION: NO characteristic issues other than char != 2 #
#############################################################




###############################################################################


################
# Polynomial C #
################


##############################################
# Computation of leading terms for each cone #
##############################################


#################
# Dumbbell Cone #
#################

leadCDumbbell = computeLTSample(pointDumbbell,S,C)
# print leadCDumbbell
# 8*a6^6*a5^6*a4^4*a3^2



#####################
# Figure Eight Cone #
#####################

leadCFigEight = computeLTSample(pointFigEight,S,C)
# print factor(leadCFigEight)
# (8) * a3^2 * a4^2 * a5^6 * a6^6 * (a4^2 - a4*a3 + a3^2)


###############
# TypeIV Cone #
###############

leadCTypeIV = computeLTSample(pointTypeIV,S,C)
# print factor(leadCTypeIV)
# (8) * a3^2 * a4^4 * a5^4 * a6^6 * (a5^2 - a5*a4 + a4^2)


##############
# TypeV Cone #
##############

leadCTypeV = computeLTSample(pointTypeV,S,C)
# print factor(leadCTypeV)
# (8) * a4^4 * a5^4 * a6^6 * (a3^2 - a3*a2 + a2^2) * (a5^2 - a5*a4 + a4^2)

###############
# TypeVI Cone #
###############

leadCTypeVI = computeLTSample(pointTypeVI,S,C)
# print factor(leadCTypeVI)
# (4) * a3^2 * a4^2 * a5^2 * a6^6 * (2*a5^4*a4^2 - 2*a5^3*a4^3 + 2*a5^2*a4^4 - 2*a5^4*a4*a3 - a5^3*a4^2*a3 - a5^2*a4^3*a3 - 2*a5*a4^4*a3 + 2*a5^4*a3^2 - a5^3*a4*a3^2 + 6*a5^2*a4^2*a3^2 - a5*a4^3*a3^2 + 2*a4^4*a3^2 - 2*a5^3*a3^3 - a5^2*a4*a3^3 - a5*a4^2*a3^3 - 2*a4^3*a3^3 + 2*a5^2*a3^4 - 2*a5*a4*a3^4 + 2*a4^2*a3^4)

################
# TypeVII Cone #
################

leadCTypeVII = computeLTSample(pointTypeVII,S,C)
# print factor(leadCTypeVII)
# (2) * a6^6 * (4*a5^6*a4^4*a3^2 - 4*a5^5*a4^5*a3^2 + 4*a5^4*a4^6*a3^2 - 4*a5^6*a4^3*a3^3 - 2*a5^5*a4^4*a3^3 - 2*a5^4*a4^5*a3^3 - 4*a5^3*a4^6*a3^3 + 4*a5^6*a4^2*a3^4 - 2*a5^5*a4^3*a3^4 + 12*a5^4*a4^4*a3^4 - 2*a5^3*a4^5*a3^4 + 4*a5^2*a4^6*a3^4 - 4*a5^5*a4^2*a3^5 - 2*a5^4*a4^3*a3^5 - 2*a5^3*a4^4*a3^5 - 4*a5^2*a4^5*a3^5 + 4*a5^4*a4^2*a3^6 - 4*a5^3*a4^3*a3^6 + 4*a5^2*a4^4*a3^6 - 4*a5^6*a4^4*a3*a2 + 4*a5^5*a4^5*a3*a2 - 4*a5^4*a4^6*a3*a2 - 2*a5^6*a4^3*a3^2*a2 + a5^5*a4^4*a3^2*a2 + a5^4*a4^5*a3^2*a2 - 2*a5^3*a4^6*a3^2*a2 - 2*a5^6*a4^2*a3^3*a2 + 20*a5^5*a4^3*a3^3*a2 - 14*a5^4*a4^4*a3^3*a2 + 20*a5^3*a4^5*a3^3*a2 - 2*a5^2*a4^6*a3^3*a2 - 4*a5^6*a4*a3^4*a2 + a5^5*a4^2*a3^4*a2 - 14*a5^4*a4^3*a3^4*a2 - 14*a5^3*a4^4*a3^4*a2 + a5^2*a4^5*a3^4*a2 - 4*a5*a4^6*a3^4*a2 + 4*a5^5*a4*a3^5*a2 + a5^4*a4^2*a3^5*a2 + 20*a5^3*a4^3*a3^5*a2 + a5^2*a4^4*a3^5*a2 + 4*a5*a4^5*a3^5*a2 - 4*a5^4*a4*a3^6*a2 - 2*a5^3*a4^2*a3^6*a2 - 2*a5^2*a4^3*a3^6*a2 - 4*a5*a4^4*a3^6*a2 + 4*a5^6*a4^4*a2^2 - 4*a5^5*a4^5*a2^2 + 4*a5^4*a4^6*a2^2 - 2*a5^6*a4^3*a3*a2^2 + a5^5*a4^4*a3*a2^2 + a5^4*a4^5*a3*a2^2 - 2*a5^3*a4^6*a3*a2^2 + 12*a5^6*a4^2*a3^2*a2^2 - 14*a5^5*a4^3*a3^2*a2^2 + 16*a5^4*a4^4*a3^2*a2^2 - 14*a5^3*a4^5*a3^2*a2^2 + 12*a5^2*a4^6*a3^2*a2^2 - 2*a5^6*a4*a3^3*a2^2 - 14*a5^5*a4^2*a3^3*a2^2 - 2*a5^4*a4^3*a3^3*a2^2 - 2*a5^3*a4^4*a3^3*a2^2 - 14*a5^2*a4^5*a3^3*a2^2 - 2*a5*a4^6*a3^3*a2^2 + 4*a5^6*a3^4*a2^2 + a5^5*a4*a3^4*a2^2 + 16*a5^4*a4^2*a3^4*a2^2 - 2*a5^3*a4^3*a3^4*a2^2 + 16*a5^2*a4^4*a3^4*a2^2 + a5*a4^5*a3^4*a2^2 + 4*a4^6*a3^4*a2^2 - 4*a5^5*a3^5*a2^2 + a5^4*a4*a3^5*a2^2 - 14*a5^3*a4^2*a3^5*a2^2 - 14*a5^2*a4^3*a3^5*a2^2 + a5*a4^4*a3^5*a2^2 - 4*a4^5*a3^5*a2^2 + 4*a5^4*a3^6*a2^2 - 2*a5^3*a4*a3^6*a2^2 + 12*a5^2*a4^2*a3^6*a2^2 - 2*a5*a4^3*a3^6*a2^2 + 4*a4^4*a3^6*a2^2 - 4*a5^6*a4^3*a2^3 - 2*a5^5*a4^4*a2^3 - 2*a5^4*a4^5*a2^3 - 4*a5^3*a4^6*a2^3 - 2*a5^6*a4^2*a3*a2^3 + 20*a5^5*a4^3*a3*a2^3 - 14*a5^4*a4^4*a3*a2^3 + 20*a5^3*a4^5*a3*a2^3 - 2*a5^2*a4^6*a3*a2^3 - 2*a5^6*a4*a3^2*a2^3 - 14*a5^5*a4^2*a3^2*a2^3 - 2*a5^4*a4^3*a3^2*a2^3 - 2*a5^3*a4^4*a3^2*a2^3 - 14*a5^2*a4^5*a3^2*a2^3 - 2*a5*a4^6*a3^2*a2^3 - 4*a5^6*a3^3*a2^3 + 20*a5^5*a4*a3^3*a2^3 - 2*a5^4*a4^2*a3^3*a2^3 + 24*a5^3*a4^3*a3^3*a2^3 - 2*a5^2*a4^4*a3^3*a2^3 + 20*a5*a4^5*a3^3*a2^3 - 4*a4^6*a3^3*a2^3 - 2*a5^5*a3^4*a2^3 - 14*a5^4*a4*a3^4*a2^3 - 2*a5^3*a4^2*a3^4*a2^3 - 2*a5^2*a4^3*a3^4*a2^3 - 14*a5*a4^4*a3^4*a2^3 - 2*a4^5*a3^4*a2^3 - 2*a5^4*a3^5*a2^3 + 20*a5^3*a4*a3^5*a2^3 - 14*a5^2*a4^2*a3^5*a2^3 + 20*a5*a4^3*a3^5*a2^3 - 2*a4^4*a3^5*a2^3 - 4*a5^3*a3^6*a2^3 - 2*a5^2*a4*a3^6*a2^3 - 2*a5*a4^2*a3^6*a2^3 - 4*a4^3*a3^6*a2^3 + 4*a5^6*a4^2*a2^4 - 2*a5^5*a4^3*a2^4 + 12*a5^4*a4^4*a2^4 - 2*a5^3*a4^5*a2^4 + 4*a5^2*a4^6*a2^4 - 4*a5^6*a4*a3*a2^4 + a5^5*a4^2*a3*a2^4 - 14*a5^4*a4^3*a3*a2^4 - 14*a5^3*a4^4*a3*a2^4 + a5^2*a4^5*a3*a2^4 - 4*a5*a4^6*a3*a2^4 + 4*a5^6*a3^2*a2^4 + a5^5*a4*a3^2*a2^4 + 16*a5^4*a4^2*a3^2*a2^4 - 2*a5^3*a4^3*a3^2*a2^4 + 16*a5^2*a4^4*a3^2*a2^4 + a5*a4^5*a3^2*a2^4 + 4*a4^6*a3^2*a2^4 - 2*a5^5*a3^3*a2^4 - 14*a5^4*a4*a3^3*a2^4 - 2*a5^3*a4^2*a3^3*a2^4 - 2*a5^2*a4^3*a3^3*a2^4 - 14*a5*a4^4*a3^3*a2^4 - 2*a4^5*a3^3*a2^4 + 12*a5^4*a3^4*a2^4 - 14*a5^3*a4*a3^4*a2^4 + 16*a5^2*a4^2*a3^4*a2^4 - 14*a5*a4^3*a3^4*a2^4 + 12*a4^4*a3^4*a2^4 - 2*a5^3*a3^5*a2^4 + a5^2*a4*a3^5*a2^4 + a5*a4^2*a3^5*a2^4 - 2*a4^3*a3^5*a2^4 + 4*a5^2*a3^6*a2^4 - 4*a5*a4*a3^6*a2^4 + 4*a4^2*a3^6*a2^4 - 4*a5^5*a4^2*a2^5 - 2*a5^4*a4^3*a2^5 - 2*a5^3*a4^4*a2^5 - 4*a5^2*a4^5*a2^5 + 4*a5^5*a4*a3*a2^5 + a5^4*a4^2*a3*a2^5 + 20*a5^3*a4^3*a3*a2^5 + a5^2*a4^4*a3*a2^5 + 4*a5*a4^5*a3*a2^5 - 4*a5^5*a3^2*a2^5 + a5^4*a4*a3^2*a2^5 - 14*a5^3*a4^2*a3^2*a2^5 - 14*a5^2*a4^3*a3^2*a2^5 + a5*a4^4*a3^2*a2^5 - 4*a4^5*a3^2*a2^5 - 2*a5^4*a3^3*a2^5 + 20*a5^3*a4*a3^3*a2^5 - 14*a5^2*a4^2*a3^3*a2^5 + 20*a5*a4^3*a3^3*a2^5 - 2*a4^4*a3^3*a2^5 - 2*a5^3*a3^4*a2^5 + a5^2*a4*a3^4*a2^5 + a5*a4^2*a3^4*a2^5 - 2*a4^3*a3^4*a2^5 - 4*a5^2*a3^5*a2^5 + 4*a5*a4*a3^5*a2^5 - 4*a4^2*a3^5*a2^5 + 4*a5^4*a4^2*a2^6 - 4*a5^3*a4^3*a2^6 + 4*a5^2*a4^4*a2^6 - 4*a5^4*a4*a3*a2^6 - 2*a5^3*a4^2*a3*a2^6 - 2*a5^2*a4^3*a3*a2^6 - 4*a5*a4^4*a3*a2^6 + 4*a5^4*a3^2*a2^6 - 2*a5^3*a4*a3^2*a2^6 + 12*a5^2*a4^2*a3^2*a2^6 - 2*a5*a4^3*a3^2*a2^6 + 4*a4^4*a3^2*a2^6 - 4*a5^3*a3^3*a2^6 - 2*a5^2*a4*a3^3*a2^6 - 2*a5*a4^2*a3^3*a2^6 - 4*a4^3*a3^3*a2^6 + 4*a5^2*a3^4*a2^6 - 4*a5*a4*a3^4*a2^6 + 4*a4^2*a3^4*a2^6)



##############
# Theta Cone #
##############

leadCTTheta = computeLTSample(pointTheta,SS,CT)
# print factor(leadCTTheta)
# (8) * a3^6 * a5^6 * a6^6


#############################################################
# CONCLUSION: NO characteristic issues other than char != 2 #
#############################################################



################################################################################


#################
# Polynomial Q4 #
#################


########################################################
# Computation of leading terms for each non Theta cone #
########################################################


#################
# Dumbbell Cone #
#################

leadQ4Dumbbell = computeLTSample(pointDumbbell,S,Q4)
`# print leadQ4Dumbbell
# -8*a6^6*a5^6*a4^4*a3^2


#####################
# Figure Eight Cone #
#####################

leadQ4FigEight = computeLTSample(pointFigEight,S,Q4)
# print factor(leadQ4FigEight)
# (-8) * a3^2 * a4^2 * (a4 - a3)^2 * a5^6 * a6^6


###############
# TypeIV Cone #
###############

leadQ4TypeIV = computeLTSample(pointTypeIV,S,Q4)
# print factor(leadQ4TypeIV)
# (-8) * a3^2 * a4^4 * a5^4 * a6^6 * (a5^2 - a5*a4 + a4^2)

##############
# TypeV Cone #
##############

leadQ4TypeV = computeLTSample(pointTypeV,S,Q4)
# print factor(leadQ4TypeV)
# (-8) * a4^4 * a5^4 * a6^6 * (a3^2 - a3*a2 + a2^2) * (a5^2 - a5*a4 + a4^2)

###############
# TypeVI Cone #
###############

leadQ4TypeVI = computeLTSample(pointTypeVI,S,Q4)
# print factor(leadQ4TypeVI)
# (-8) * a3^2 * a4^2 * a5^2 * a6^6 * (a5^4*a4^2 - a5^3*a4^3 + a5^2*a4^4 - 2*a5^4*a4*a3 + a5^3*a4^2*a3 + a5^2*a4^3*a3 - 2*a5*a4^4*a3 + a5^4*a3^2 + a5^3*a4*a3^2 - 3*a5^2*a4^2*a3^2 + a5*a4^3*a3^2 + a4^4*a3^2 - a5^3*a3^3 + a5^2*a4*a3^3 + a5*a4^2*a3^3 - a4^3*a3^3 + a5^2*a3^4 - 2*a5*a4*a3^4 + a4^2*a3^4)

################
# TypeVII Cone #
################

leadQ4TypeVII = computeLTSample(pointTypeVII,S,Q4)
# print factor(leadQ4TypeVII)
# (-8) * a6^6 * (a5^6*a4^4*a3^2 - a5^5*a4^5*a3^2 + a5^4*a4^6*a3^2 - 2*a5^6*a4^3*a3^3 + a5^5*a4^4*a3^3 + a5^4*a4^5*a3^3 - 2*a5^3*a4^6*a3^3 + a5^6*a4^2*a3^4 + a5^5*a4^3*a3^4 - 3*a5^4*a4^4*a3^4 + a5^3*a4^5*a3^4 + a5^2*a4^6*a3^4 - a5^5*a4^2*a3^5 + a5^4*a4^3*a3^5 + a5^3*a4^4*a3^5 - a5^2*a4^5*a3^5 + a5^4*a4^2*a3^6 - 2*a5^3*a4^3*a3^6 + a5^2*a4^4*a3^6 - a5^6*a4^4*a3*a2 + a5^5*a4^5*a3*a2 - a5^4*a4^6*a3*a2 + a5^6*a4^3*a3^2*a2 - 2*a5^5*a4^4*a3^2*a2 - 2*a5^4*a4^5*a3^2*a2 + a5^3*a4^6*a3^2*a2 + a5^6*a4^2*a3^3*a2 + 2*a5^5*a4^3*a3^3*a2 + a5^4*a4^4*a3^3*a2 + 2*a5^3*a4^5*a3^3*a2 + a5^2*a4^6*a3^3*a2 - a5^6*a4*a3^4*a2 - 2*a5^5*a4^2*a3^4*a2 + a5^4*a4^3*a3^4*a2 + a5^3*a4^4*a3^4*a2 - 2*a5^2*a4^5*a3^4*a2 - a5*a4^6*a3^4*a2 + a5^5*a4*a3^5*a2 - 2*a5^4*a4^2*a3^5*a2 + 2*a5^3*a4^3*a3^5*a2 - 2*a5^2*a4^4*a3^5*a2 + a5*a4^5*a3^5*a2 - a5^4*a4*a3^6*a2 + a5^3*a4^2*a3^6*a2 + a5^2*a4^3*a3^6*a2 - a5*a4^4*a3^6*a2 + a5^6*a4^4*a2^2 - a5^5*a4^5*a2^2 + a5^4*a4^6*a2^2 + a5^6*a4^3*a3*a2^2 - 2*a5^5*a4^4*a3*a2^2 - 2*a5^4*a4^5*a3*a2^2 + a5^3*a4^6*a3*a2^2 - 3*a5^6*a4^2*a3^2*a2^2 + a5^5*a4^3*a3^2*a2^2 + 16*a5^4*a4^4*a3^2*a2^2 + a5^3*a4^5*a3^2*a2^2 - 3*a5^2*a4^6*a3^2*a2^2 + a5^6*a4*a3^3*a2^2 + a5^5*a4^2*a3^3*a2^2 - 14*a5^4*a4^3*a3^3*a2^2 - 14*a5^3*a4^4*a3^3*a2^2 + a5^2*a4^5*a3^3*a2^2 + a5*a4^6*a3^3*a2^2 + a5^6*a3^4*a2^2 - 2*a5^5*a4*a3^4*a2^2 + 16*a5^4*a4^2*a3^4*a2^2 - 14*a5^3*a4^3*a3^4*a2^2 + 16*a5^2*a4^4*a3^4*a2^2 - 2*a5*a4^5*a3^4*a2^2 + a4^6*a3^4*a2^2 - a5^5*a3^5*a2^2 - 2*a5^4*a4*a3^5*a2^2 + a5^3*a4^2*a3^5*a2^2 + a5^2*a4^3*a3^5*a2^2 - 2*a5*a4^4*a3^5*a2^2 - a4^5*a3^5*a2^2 + a5^4*a3^6*a2^2 + a5^3*a4*a3^6*a2^2 - 3*a5^2*a4^2*a3^6*a2^2 + a5*a4^3*a3^6*a2^2 + a4^4*a3^6*a2^2 - 2*a5^6*a4^3*a2^3 + a5^5*a4^4*a2^3 + a5^4*a4^5*a2^3 - 2*a5^3*a4^6*a2^3 + a5^6*a4^2*a3*a2^3 + 2*a5^5*a4^3*a3*a2^3 + a5^4*a4^4*a3*a2^3 + 2*a5^3*a4^5*a3*a2^3 + a5^2*a4^6*a3*a2^3 + a5^6*a4*a3^2*a2^3 + a5^5*a4^2*a3^2*a2^3 - 14*a5^4*a4^3*a3^2*a2^3 - 14*a5^3*a4^4*a3^2*a2^3 + a5^2*a4^5*a3^2*a2^3 + a5*a4^6*a3^2*a2^3 - 2*a5^6*a3^3*a2^3 + 2*a5^5*a4*a3^3*a2^3 - 14*a5^4*a4^2*a3^3*a2^3 + 66*a5^3*a4^3*a3^3*a2^3 - 14*a5^2*a4^4*a3^3*a2^3 + 2*a5*a4^5*a3^3*a2^3 - 2*a4^6*a3^3*a2^3 + a5^5*a3^4*a2^3 + a5^4*a4*a3^4*a2^3 - 14*a5^3*a4^2*a3^4*a2^3 - 14*a5^2*a4^3*a3^4*a2^3 + a5*a4^4*a3^4*a2^3 + a4^5*a3^4*a2^3 + a5^4*a3^5*a2^3 + 2*a5^3*a4*a3^5*a2^3 + a5^2*a4^2*a3^5*a2^3 + 2*a5*a4^3*a3^5*a2^3 + a4^4*a3^5*a2^3 - 2*a5^3*a3^6*a2^3 + a5^2*a4*a3^6*a2^3 + a5*a4^2*a3^6*a2^3 - 2*a4^3*a3^6*a2^3 + a5^6*a4^2*a2^4 + a5^5*a4^3*a2^4 - 3*a5^4*a4^4*a2^4 + a5^3*a4^5*a2^4 + a5^2*a4^6*a2^4 - a5^6*a4*a3*a2^4 - 2*a5^5*a4^2*a3*a2^4 + a5^4*a4^3*a3*a2^4 + a5^3*a4^4*a3*a2^4 - 2*a5^2*a4^5*a3*a2^4 - a5*a4^6*a3*a2^4 + a5^6*a3^2*a2^4 - 2*a5^5*a4*a3^2*a2^4 + 16*a5^4*a4^2*a3^2*a2^4 - 14*a5^3*a4^3*a3^2*a2^4 + 16*a5^2*a4^4*a3^2*a2^4 - 2*a5*a4^5*a3^2*a2^4 + a4^6*a3^2*a2^4 + a5^5*a3^3*a2^4 + a5^4*a4*a3^3*a2^4 - 14*a5^3*a4^2*a3^3*a2^4 - 14*a5^2*a4^3*a3^3*a2^4 + a5*a4^4*a3^3*a2^4 + a4^5*a3^3*a2^4 - 3*a5^4*a3^4*a2^4 + a5^3*a4*a3^4*a2^4 + 16*a5^2*a4^2*a3^4*a2^4 + a5*a4^3*a3^4*a2^4 - 3*a4^4*a3^4*a2^4 + a5^3*a3^5*a2^4 - 2*a5^2*a4*a3^5*a2^4 - 2*a5*a4^2*a3^5*a2^4 + a4^3*a3^5*a2^4 + a5^2*a3^6*a2^4 - a5*a4*a3^6*a2^4 + a4^2*a3^6*a2^4 - a5^5*a4^2*a2^5 + a5^4*a4^3*a2^5 + a5^3*a4^4*a2^5 - a5^2*a4^5*a2^5 + a5^5*a4*a3*a2^5 - 2*a5^4*a4^2*a3*a2^5 + 2*a5^3*a4^3*a3*a2^5 - 2*a5^2*a4^4*a3*a2^5 + a5*a4^5*a3*a2^5 - a5^5*a3^2*a2^5 - 2*a5^4*a4*a3^2*a2^5 + a5^3*a4^2*a3^2*a2^5 + a5^2*a4^3*a3^2*a2^5 - 2*a5*a4^4*a3^2*a2^5 - a4^5*a3^2*a2^5 + a5^4*a3^3*a2^5 + 2*a5^3*a4*a3^3*a2^5 + a5^2*a4^2*a3^3*a2^5 + 2*a5*a4^3*a3^3*a2^5 + a4^4*a3^3*a2^5 + a5^3*a3^4*a2^5 - 2*a5^2*a4*a3^4*a2^5 - 2*a5*a4^2*a3^4*a2^5 + a4^3*a3^4*a2^5 - a5^2*a3^5*a2^5 + a5*a4*a3^5*a2^5 - a4^2*a3^5*a2^5 + a5^4*a4^2*a2^6 - 2*a5^3*a4^3*a2^6 + a5^2*a4^4*a2^6 - a5^4*a4*a3*a2^6 + a5^3*a4^2*a3*a2^6 + a5^2*a4^3*a3*a2^6 - a5*a4^4*a3*a2^6 + a5^4*a3^2*a2^6 + a5^3*a4*a3^2*a2^6 - 3*a5^2*a4^2*a3^2*a2^6 + a5*a4^3*a3^2*a2^6 + a4^4*a3^2*a2^6 - 2*a5^3*a3^3*a2^6 + a5^2*a4*a3^3*a2^6 + a5*a4^2*a3^3*a2^6 - 2*a4^3*a3^3*a2^6 + a5^2*a3^4*a2^6 - a5*a4*a3^4*a2^6 + a4^2*a3^4*a2^6)


#############################################################
# CONCLUSION: NO characteristic issues other than char != 2 #
#############################################################



#######################################
# Theta subdivision and sample points #
#######################################

# The following sample points were computed in "GrobnerConeComputationsQ4.sage"

shiftedPointThetaGfan = {0: [6, 5, 1, 3, 2, 1], 1: [6, 5, 2, 3, 1, 0], 2: [6, 5, 2, 4, 2, 1]}

pointCell0 = shiftedPointThetaGfan[0]
pointCell1 = shiftedPointThetaGfan[1]
pointCell2 = shiftedPointThetaGfan[2]

pointCell01 = [0, -1, -4, -3, -4, -5]
pointCell02 = [0, -1, -4, -2, -3, -4]
pointCell12 = [0, -1, -3, -2, -4, -5]
pointCell012 = [0, -1, -3, -2, -3, -4]



########################################################
# Construction of initial forms Theta Cone subdivision #
########################################################

##########
# Cell 0 # -- Theta 2 (L_2 is smallest)
##########

leadQ4Cell0 = computeLTSample(shiftedPointThetaGfan[0],SS,QT4)
# print factor(leadQ4Cell0)
# (-8) * a2^2 * a3^4 * a5^6 * a6^6

##########
# Cell 1 #  -- Theta 0 (L_0 is smallest)
##########

leadQ4Cell1 = computeLTSample(shiftedPointThetaGfan[1],SS,QT4)
# print factor(leadQ4Cell1)
# (-8) * x34^2 * a3^4 * a5^6 * a6^6

##########
# Cell 2 #  -- Theta 1 (L_1 is smallest)
##########

leadQ4Cell2 = computeLTSample(shiftedPointThetaGfan[2],SS,QT4)
# print factor(leadQ4Cell2)
# (-8) * a5^4 * a6^6 * a3^8

###########
# Cell 01 #
###########

leadQ4Cell01 = computeLTSample(pointCell01,SS,QT4)
# print factor(leadQ4Cell01)
# (-8) * a3^4 * a5^6 * a6^6 * (x34^2 + a2^2)

###########
# Cell 02 #
###########

leadQ4Cell02 = computeLTSample(pointCell02,SS,QT4)
# print factor(leadQ4Cell02)
# (-8) * a3^4 * a5^4 * a6^6 * (a3^4 + a5^2*a2^2)

###########
# Cell 12 #
###########

leadQ4Cell12 = computeLTSample(pointCell12,SS,QT4)
# print factor(leadQ4Cell12)
# (-8) * a3^4 * a5^4 * a6^6 * (a5^2*x34^2 + a3^4)


############
# Cell 012 #
############

leadQ4Cell012 = computeLTSample(pointCell012,SS,QT4)
# print factor(leadQ4Cell012)
# (-8) * a3^4 * a5^4 * a6^6 * (a5^2*x34^2 + a3^4 + a5^2*a2^2)


#############################################################
# CONCLUSION: NO characteristic issues other than char != 2 #
#############################################################


